@@ -269,15 +269,23 @@ class CondType12(Conductor):
         S += getsizeof(self.Kwoh)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Conductor
-        CondType12_dict = super(CondType12, self).as_dict(**kwargs)
+        CondType12_dict = super(CondType12, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         CondType12_dict["Wwire"] = self.Wwire
         CondType12_dict["Wins_cond"] = self.Wins_cond
         CondType12_dict["Nwppc"] = self.Nwppc
