@@ -37,6 +37,16 @@ try:
 except ImportError as error:
     comp_joule_losses = error
 
+try:
+    from ..Methods.Simulation.EEC_PMSM.comp_BEMF_harmonics import comp_BEMF_harmonics
+except ImportError as error:
+    comp_BEMF_harmonics = error
+
+try:
+    from ..Methods.Simulation.EEC_PMSM.comp_torque_sync_rel import comp_torque_sync_rel
+except ImportError as error:
+    comp_torque_sync_rel = error
+
 
 from ._check import InitUnKnowClassError
 from .IndMag import IndMag
@@ -91,6 +101,30 @@ class EEC_PMSM(EEC):
         )
     else:
         comp_joule_losses = comp_joule_losses
+    # cf Methods.Simulation.EEC_PMSM.comp_BEMF_harmonics
+    if isinstance(comp_BEMF_harmonics, ImportError):
+        comp_BEMF_harmonics = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use EEC_PMSM method comp_BEMF_harmonics: "
+                    + str(comp_BEMF_harmonics)
+                )
+            )
+        )
+    else:
+        comp_BEMF_harmonics = comp_BEMF_harmonics
+    # cf Methods.Simulation.EEC_PMSM.comp_torque_sync_rel
+    if isinstance(comp_torque_sync_rel, ImportError):
+        comp_torque_sync_rel = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use EEC_PMSM method comp_torque_sync_rel: "
+                    + str(comp_torque_sync_rel)
+                )
+            )
+        )
+    else:
+        comp_torque_sync_rel = comp_torque_sync_rel
     # save and copy methods are available in all object
     save = save
     copy = copy
