@@ -22,11 +22,6 @@ try:
 except ImportError as error:
     comp_fluxlinkage = error
 
-try:
-    from ..Methods.Simulation.FluxLinkFEMM.solve_FEMM import solve_FEMM
-except ImportError as error:
-    solve_FEMM = error
-
 
 from ._check import InitUnKnowClassError
 
@@ -36,7 +31,6 @@ class FluxLinkFEMM(FluxLink):
 
     VERSION = 1
 
-    # Check ImportError to remove unnecessary dependencies in unused method
     # cf Methods.Simulation.FluxLinkFEMM.comp_fluxlinkage
     if isinstance(comp_fluxlinkage, ImportError):
         comp_fluxlinkage = property(
@@ -49,17 +43,6 @@ class FluxLinkFEMM(FluxLink):
         )
     else:
         comp_fluxlinkage = comp_fluxlinkage
-    # cf Methods.Simulation.FluxLinkFEMM.solve_FEMM
-    if isinstance(solve_FEMM, ImportError):
-        solve_FEMM = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use FluxLinkFEMM method solve_FEMM: " + str(solve_FEMM)
-                )
-            )
-        )
-    else:
-        solve_FEMM = solve_FEMM
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -74,6 +57,7 @@ class FluxLinkFEMM(FluxLink):
         is_periodicity_a=False,
         Nt_tot=5,
         Kgeo_fineness=0.5,
+        nb_worker=1,
         init_dict=None,
         init_str=None,
     ):
@@ -104,6 +88,8 @@ class FluxLinkFEMM(FluxLink):
                 Nt_tot = init_dict["Nt_tot"]
             if "Kgeo_fineness" in list(init_dict.keys()):
                 Kgeo_fineness = init_dict["Kgeo_fineness"]
+            if "nb_worker" in list(init_dict.keys()):
+                nb_worker = init_dict["nb_worker"]
         # Set the properties (value check and convertion are done in setter)
         self.FEMM_dict = FEMM_dict
         self.type_calc_leakage = type_calc_leakage
@@ -111,6 +97,7 @@ class FluxLinkFEMM(FluxLink):
         self.is_periodicity_a = is_periodicity_a
         self.Nt_tot = Nt_tot
         self.Kgeo_fineness = Kgeo_fineness
+        self.nb_worker = nb_worker
         # Call FluxLink init
         super(FluxLinkFEMM, self).__init__()
         # The class is frozen (in FluxLink init), for now it's impossible to
@@ -130,6 +117,7 @@ class FluxLinkFEMM(FluxLink):
         FluxLinkFEMM_str += "is_periodicity_a = " + str(self.is_periodicity_a) + linesep
         FluxLinkFEMM_str += "Nt_tot = " + str(self.Nt_tot) + linesep
         FluxLinkFEMM_str += "Kgeo_fineness = " + str(self.Kgeo_fineness) + linesep
+        FluxLinkFEMM_str += "nb_worker = " + str(self.nb_worker) + linesep
         return FluxLinkFEMM_str
 
     def __eq__(self, other):
@@ -153,6 +141,8 @@ class FluxLinkFEMM(FluxLink):
             return False
         if other.Kgeo_fineness != self.Kgeo_fineness:
             return False
+        if other.nb_worker != self.nb_worker:
+            return False
         return True
 
     def compare(self, other, name="self", ignore_list=None):
@@ -178,6 +168,8 @@ class FluxLinkFEMM(FluxLink):
             diff_list.append(name + ".Nt_tot")
         if other._Kgeo_fineness != self._Kgeo_fineness:
             diff_list.append(name + ".Kgeo_fineness")
+        if other._nb_worker != self._nb_worker:
+            diff_list.append(name + ".nb_worker")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -197,6 +189,7 @@ class FluxLinkFEMM(FluxLink):
         S += getsizeof(self.is_periodicity_a)
         S += getsizeof(self.Nt_tot)
         S += getsizeof(self.Kgeo_fineness)
+        S += getsizeof(self.nb_worker)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -224,6 +217,7 @@ class FluxLinkFEMM(FluxLink):
         FluxLinkFEMM_dict["is_periodicity_a"] = self.is_periodicity_a
         FluxLinkFEMM_dict["Nt_tot"] = self.Nt_tot
         FluxLinkFEMM_dict["Kgeo_fineness"] = self.Kgeo_fineness
+        FluxLinkFEMM_dict["nb_worker"] = self.nb_worker
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         FluxLinkFEMM_dict["__class__"] = "FluxLinkFEMM"
@@ -238,6 +232,7 @@ class FluxLinkFEMM(FluxLink):
         self.is_periodicity_a = None
         self.Nt_tot = None
         self.Kgeo_fineness = None
+        self.nb_worker = None
         # Set to None the properties inherited from FluxLink
         super(FluxLinkFEMM, self)._set_None()
 
@@ -352,3 +347,21 @@ class FluxLinkFEMM(FluxLink):
         :Type: float
         """,
     )
+
+    def _get_nb_worker(self):
+        """getter of nb_worker"""
+        return self._nb_worker
+
+    def _set_nb_worker(self, value):
+        """setter of nb_worker"""
+        check_var("nb_worker", value, "int")
+        self._nb_worker = value
+
+    nb_worker = property(
+        fget=_get_nb_worker,
+        fset=_set_nb_worker,
+        doc=u"""To run FEMM in parallel (the parallelization is on the time loop)
+
+        :Type: int
+        """,
+    )
