@@ -241,9 +241,13 @@ class Frame(FrozenClass):
         S += getsizeof(self.mat_type)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
@@ -255,7 +259,11 @@ class Frame(FrozenClass):
         if self.mat_type is None:
             Frame_dict["mat_type"] = None
         else:
-            Frame_dict["mat_type"] = self.mat_type.as_dict(**kwargs)
+            Frame_dict["mat_type"] = self.mat_type.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         # The class name is added to the dict for deserialisation purpose
         Frame_dict["__class__"] = "Frame"
         return Frame_dict
