@@ -271,15 +271,23 @@ class HoleM54(Hole):
         S += getsizeof(self.R1)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Hole
-        HoleM54_dict = super(HoleM54, self).as_dict(**kwargs)
+        HoleM54_dict = super(HoleM54, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         HoleM54_dict["H0"] = self.H0
         HoleM54_dict["H1"] = self.H1
         HoleM54_dict["W0"] = self.W0
