@@ -363,15 +363,23 @@ class HoleM58(HoleMag):
         S += getsizeof(self.magnet_0)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from HoleMag
-        HoleM58_dict = super(HoleM58, self).as_dict(**kwargs)
+        HoleM58_dict = super(HoleM58, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         HoleM58_dict["H0"] = self.H0
         HoleM58_dict["W0"] = self.W0
         HoleM58_dict["H1"] = self.H1
@@ -383,7 +391,11 @@ class HoleM58(HoleMag):
         if self.magnet_0 is None:
             HoleM58_dict["magnet_0"] = None
         else:
-            HoleM58_dict["magnet_0"] = self.magnet_0.as_dict(**kwargs)
+            HoleM58_dict["magnet_0"] = self.magnet_0.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         HoleM58_dict["__class__"] = "HoleM58"
