@@ -60,6 +60,10 @@ class ImportGenPWM(ImportMatrix):
         Vdc1=2,
         U0=1,
         type_carrier=0,
+        var_amp=20,
+        qs=3,
+        is_star=True,
+        rot_dir=-1,
         is_transpose=False,
         init_dict=None,
         init_str=None,
@@ -103,6 +107,14 @@ class ImportGenPWM(ImportMatrix):
                 U0 = init_dict["U0"]
             if "type_carrier" in list(init_dict.keys()):
                 type_carrier = init_dict["type_carrier"]
+            if "var_amp" in list(init_dict.keys()):
+                var_amp = init_dict["var_amp"]
+            if "qs" in list(init_dict.keys()):
+                qs = init_dict["qs"]
+            if "is_star" in list(init_dict.keys()):
+                is_star = init_dict["is_star"]
+            if "rot_dir" in list(init_dict.keys()):
+                rot_dir = init_dict["rot_dir"]
             if "is_transpose" in list(init_dict.keys()):
                 is_transpose = init_dict["is_transpose"]
         # Set the properties (value check and convertion are done in setter)
@@ -118,6 +130,10 @@ class ImportGenPWM(ImportMatrix):
         self.Vdc1 = Vdc1
         self.U0 = U0
         self.type_carrier = type_carrier
+        self.var_amp = var_amp
+        self.qs = qs
+        self.is_star = is_star
+        self.rot_dir = rot_dir
         # Call ImportMatrix init
         super(ImportGenPWM, self).__init__(is_transpose=is_transpose)
         # The class is frozen (in ImportMatrix init), for now it's impossible to
@@ -141,6 +157,10 @@ class ImportGenPWM(ImportMatrix):
         ImportGenPWM_str += "Vdc1 = " + str(self.Vdc1) + linesep
         ImportGenPWM_str += "U0 = " + str(self.U0) + linesep
         ImportGenPWM_str += "type_carrier = " + str(self.type_carrier) + linesep
+        ImportGenPWM_str += "var_amp = " + str(self.var_amp) + linesep
+        ImportGenPWM_str += "qs = " + str(self.qs) + linesep
+        ImportGenPWM_str += "is_star = " + str(self.is_star) + linesep
+        ImportGenPWM_str += "rot_dir = " + str(self.rot_dir) + linesep
         return ImportGenPWM_str
 
     def __eq__(self, other):
@@ -176,6 +196,14 @@ class ImportGenPWM(ImportMatrix):
             return False
         if other.type_carrier != self.type_carrier:
             return False
+        if other.var_amp != self.var_amp:
+            return False
+        if other.qs != self.qs:
+            return False
+        if other.is_star != self.is_star:
+            return False
+        if other.rot_dir != self.rot_dir:
+            return False
         return True
 
     def compare(self, other, name="self", ignore_list=None):
@@ -213,6 +241,14 @@ class ImportGenPWM(ImportMatrix):
             diff_list.append(name + ".U0")
         if other._type_carrier != self._type_carrier:
             diff_list.append(name + ".type_carrier")
+        if other._var_amp != self._var_amp:
+            diff_list.append(name + ".var_amp")
+        if other._qs != self._qs:
+            diff_list.append(name + ".qs")
+        if other._is_star != self._is_star:
+            diff_list.append(name + ".is_star")
+        if other._rot_dir != self._rot_dir:
+            diff_list.append(name + ".rot_dir")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -236,6 +272,10 @@ class ImportGenPWM(ImportMatrix):
         S += getsizeof(self.Vdc1)
         S += getsizeof(self.U0)
         S += getsizeof(self.type_carrier)
+        S += getsizeof(self.var_amp)
+        S += getsizeof(self.qs)
+        S += getsizeof(self.is_star)
+        S += getsizeof(self.rot_dir)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -267,6 +307,10 @@ class ImportGenPWM(ImportMatrix):
         ImportGenPWM_dict["Vdc1"] = self.Vdc1
         ImportGenPWM_dict["U0"] = self.U0
         ImportGenPWM_dict["type_carrier"] = self.type_carrier
+        ImportGenPWM_dict["var_amp"] = self.var_amp
+        ImportGenPWM_dict["qs"] = self.qs
+        ImportGenPWM_dict["is_star"] = self.is_star
+        ImportGenPWM_dict["rot_dir"] = self.rot_dir
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         ImportGenPWM_dict["__class__"] = "ImportGenPWM"
@@ -287,6 +331,10 @@ class ImportGenPWM(ImportMatrix):
         self.Vdc1 = None
         self.U0 = None
         self.type_carrier = None
+        self.var_amp = None
+        self.qs = None
+        self.is_star = None
+        self.rot_dir = None
         # Set to None the properties inherited from ImportMatrix
         super(ImportGenPWM, self)._set_None()
 
@@ -315,7 +363,7 @@ class ImportGenPWM(ImportMatrix):
 
     def _set_duration(self, value):
         """setter of duration"""
-        check_var("duration", value, "int", Vmin=0)
+        check_var("duration", value, "float", Vmin=0)
         self._duration = value
 
     duration = property(
@@ -323,7 +371,7 @@ class ImportGenPWM(ImportMatrix):
         fset=_set_duration,
         doc=u"""duration
 
-        :Type: int
+        :Type: float
         :min: 0
         """,
     )
@@ -427,7 +475,7 @@ class ImportGenPWM(ImportMatrix):
 
     def _set_fswi_max(self, value):
         """setter of fswi_max"""
-        check_var("fswi_max", value, "int")
+        check_var("fswi_max", value, "float")
         self._fswi_max = value
 
     fswi_max = property(
@@ -435,7 +483,7 @@ class ImportGenPWM(ImportMatrix):
         fset=_set_fswi_max,
         doc=u"""maximal switching frequency
 
-        :Type: int
+        :Type: float
         """,
     )
 
@@ -510,3 +558,75 @@ class ImportGenPWM(ImportMatrix):
         :Type: int
         """,
     )
+
+    def _get_var_amp(self):
+        """getter of var_amp"""
+        return self._var_amp
+
+    def _set_var_amp(self, value):
+        """setter of var_amp"""
+        check_var("var_amp", value, "int")
+        self._var_amp = value
+
+    var_amp = property(
+        fget=_get_var_amp,
+        fset=_set_var_amp,
+        doc=u"""percentage of variation of carrier amplitude
+
+        :Type: int
+        """,
+    )
+
+    def _get_qs(self):
+        """getter of qs"""
+        return self._qs
+
+    def _set_qs(self, value):
+        """setter of qs"""
+        check_var("qs", value, "int")
+        self._qs = value
+
+    qs = property(
+        fget=_get_qs,
+        fset=_set_qs,
+        doc=u"""number of phase
+
+        :Type: int
+        """,
+    )
+
+    def _get_is_star(self):
+        """getter of is_star"""
+        return self._is_star
+
+    def _set_is_star(self, value):
+        """setter of is_star"""
+        check_var("is_star", value, "bool")
+        self._is_star = value
+
+    is_star = property(
+        fget=_get_is_star,
+        fset=_set_is_star,
+        doc=u"""True if star coupling, False if triangle coupling
+
+        :Type: bool
+        """,
+    )
+
+    def _get_rot_dir(self):
+        """getter of rot_dir"""
+        return self._rot_dir
+
+    def _set_rot_dir(self, value):
+        """setter of rot_dir"""
+        check_var("rot_dir", value, "int")
+        self._rot_dir = value
+
+    rot_dir = property(
+        fget=_get_rot_dir,
+        fset=_set_rot_dir,
+        doc=u"""rotor rotation direction
+
+        :Type: int
+        """,
+    )
