@@ -17,20 +17,25 @@ from ._frozen import FrozenClass
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
-try:
-    from ..Methods.Simulation.Input.gen_input import gen_input
-except ImportError as error:
-    gen_input = error
-
 try:
     from ..Methods.Simulation.Input.comp_axes import comp_axes
 except ImportError as error:
     comp_axes = error
 
 try:
-    from ..Methods.Simulation.Input.comp_felec import comp_felec
+    from ..Methods.Simulation.Input.comp_axis_time import comp_axis_time
 except ImportError as error:
-    comp_felec = error
+    comp_axis_time = error
+
+try:
+    from ..Methods.Simulation.Input.comp_axis_angle import comp_axis_angle
+except ImportError as error:
+    comp_axis_angle = error
+
+try:
+    from ..Methods.Simulation.Input.comp_axis_phase import comp_axis_phase
+except ImportError as error:
+    comp_axis_phase = error
 
 
 from ..Classes.ImportMatrixVal import ImportMatrixVal
@@ -38,6 +43,7 @@ from numpy import ndarray
 from numpy import array, array_equal
 from ._check import InitUnKnowClassError
 from .ImportMatrix import ImportMatrix
+from .OP import OP
 
 
 class Input(FrozenClass):
@@ -46,15 +52,6 @@ class Input(FrozenClass):
     VERSION = 1
 
     # Check ImportError to remove unnecessary dependencies in unused method
-    # cf Methods.Simulation.Input.gen_input
-    if isinstance(gen_input, ImportError):
-        gen_input = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use Input method gen_input: " + str(gen_input))
-            )
-        )
-    else:
-        gen_input = gen_input
     # cf Methods.Simulation.Input.comp_axes
     if isinstance(comp_axes, ImportError):
         comp_axes = property(
@@ -64,15 +61,39 @@ class Input(FrozenClass):
         )
     else:
         comp_axes = comp_axes
-    # cf Methods.Simulation.Input.comp_felec
-    if isinstance(comp_felec, ImportError):
-        comp_felec = property(
+    # cf Methods.Simulation.Input.comp_axis_time
+    if isinstance(comp_axis_time, ImportError):
+        comp_axis_time = property(
             fget=lambda x: raise_(
-                ImportError("Can't use Input method comp_felec: " + str(comp_felec))
+                ImportError(
+                    "Can't use Input method comp_axis_time: " + str(comp_axis_time)
+                )
             )
         )
     else:
-        comp_felec = comp_felec
+        comp_axis_time = comp_axis_time
+    # cf Methods.Simulation.Input.comp_axis_angle
+    if isinstance(comp_axis_angle, ImportError):
+        comp_axis_angle = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Input method comp_axis_angle: " + str(comp_axis_angle)
+                )
+            )
+        )
+    else:
+        comp_axis_angle = comp_axis_angle
+    # cf Methods.Simulation.Input.comp_axis_phase
+    if isinstance(comp_axis_phase, ImportError):
+        comp_axis_phase = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Input method comp_axis_phase: " + str(comp_axis_phase)
+                )
+            )
+        )
+    else:
+        comp_axis_phase = comp_axis_phase
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -84,9 +105,9 @@ class Input(FrozenClass):
         time=None,
         angle=None,
         Nt_tot=2048,
-        Nrev=1,
+        Nrev=None,
         Na_tot=2048,
-        N0=None,
+        OP=None,
         init_dict=None,
         init_str=None,
     ):
@@ -115,8 +136,8 @@ class Input(FrozenClass):
                 Nrev = init_dict["Nrev"]
             if "Na_tot" in list(init_dict.keys()):
                 Na_tot = init_dict["Na_tot"]
-            if "N0" in list(init_dict.keys()):
-                N0 = init_dict["N0"]
+            if "OP" in list(init_dict.keys()):
+                OP = init_dict["OP"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.time = time
@@ -124,7 +145,7 @@ class Input(FrozenClass):
         self.Nt_tot = Nt_tot
         self.Nrev = Nrev
         self.Na_tot = Na_tot
-        self.N0 = N0
+        self.OP = OP
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -150,7 +171,11 @@ class Input(FrozenClass):
         Input_str += "Nt_tot = " + str(self.Nt_tot) + linesep
         Input_str += "Nrev = " + str(self.Nrev) + linesep
         Input_str += "Na_tot = " + str(self.Na_tot) + linesep
-        Input_str += "N0 = " + str(self.N0) + linesep
+        if self.OP is not None:
+            tmp = self.OP.__str__().replace(linesep, linesep + "\t").rstrip("\t")
+            Input_str += "OP = " + tmp
+        else:
+            Input_str += "OP = None" + linesep + linesep
         return Input_str
 
     def __eq__(self, other):
@@ -168,7 +193,7 @@ class Input(FrozenClass):
             return False
         if other.Na_tot != self.Na_tot:
             return False
-        if other.N0 != self.N0:
+        if other.OP != self.OP:
             return False
         return True
 
@@ -198,8 +223,12 @@ class Input(FrozenClass):
             diff_list.append(name + ".Nrev")
         if other._Na_tot != self._Na_tot:
             diff_list.append(name + ".Na_tot")
-        if other._N0 != self._N0:
-            diff_list.append(name + ".N0")
+        if (other.OP is None and self.OP is not None) or (
+            other.OP is not None and self.OP is None
+        ):
+            diff_list.append(name + ".OP None mismatch")
+        elif self.OP is not None:
+            diff_list.extend(self.OP.compare(other.OP, name=name + ".OP"))
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -213,7 +242,7 @@ class Input(FrozenClass):
         S += getsizeof(self.Nt_tot)
         S += getsizeof(self.Nrev)
         S += getsizeof(self.Na_tot)
-        S += getsizeof(self.N0)
+        S += getsizeof(self.OP)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -247,7 +276,14 @@ class Input(FrozenClass):
         Input_dict["Nt_tot"] = self.Nt_tot
         Input_dict["Nrev"] = self.Nrev
         Input_dict["Na_tot"] = self.Na_tot
-        Input_dict["N0"] = self.N0
+        if self.OP is None:
+            Input_dict["OP"] = None
+        else:
+            Input_dict["OP"] = self.OP.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         # The class name is added to the dict for deserialisation purpose
         Input_dict["__class__"] = "Input"
         return Input_dict
@@ -262,7 +298,8 @@ class Input(FrozenClass):
         self.Nt_tot = None
         self.Nrev = None
         self.Na_tot = None
-        self.N0 = None
+        if self.OP is not None:
+            self.OP._set_None()
 
     def _get_time(self):
         """getter of time"""
@@ -387,20 +424,30 @@ class Input(FrozenClass):
         """,
     )
 
-    def _get_N0(self):
-        """getter of N0"""
-        return self._N0
+    def _get_OP(self):
+        """getter of OP"""
+        return self._OP
 
-    def _set_N0(self, value):
-        """setter of N0"""
-        check_var("N0", value, "float")
-        self._N0 = value
+    def _set_OP(self, value):
+        """setter of OP"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class("pyleecan.Classes", value.get("__class__"), "OP")
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = OP()
+        check_var("OP", value, "OP")
+        self._OP = value
 
-    N0 = property(
-        fget=_get_N0,
-        fset=_set_N0,
-        doc=u"""Rotor speed
+        if self._OP is not None:
+            self._OP.parent = self
 
-        :Type: float
+    OP = property(
+        fget=_get_OP,
+        fset=_set_OP,
+        doc=u"""Operating Point
+
+        :Type: OP
         """,
     )
