@@ -67,21 +67,22 @@ try:
 except ImportError as error:
     comp_angle_d_axis = error
 
-try:
-    from ..Methods.Machine.LamHole.comp_periodicity import comp_periodicity
-except ImportError as error:
-    comp_periodicity = error
-
 try:
     from ..Methods.Machine.LamHole.set_pole_pair_number import set_pole_pair_number
 except ImportError as error:
     set_pole_pair_number = error
 
+try:
+    from ..Methods.Machine.LamHole.get_Zs import get_Zs
+except ImportError as error:
+    get_Zs = error
+
 
 from ._check import InitUnKnowClassError
 from .Hole import Hole
 from .Material import Material
 from .Notch import Notch
+from .Skew import Skew
 from .Bore import Bore
 
 
@@ -199,18 +200,6 @@ class LamHole(Lamination):
         )
     else:
         comp_angle_d_axis = comp_angle_d_axis
-    # cf Methods.Machine.LamHole.comp_periodicity
-    if isinstance(comp_periodicity, ImportError):
-        comp_periodicity = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use LamHole method comp_periodicity: "
-                    + str(comp_periodicity)
-                )
-            )
-        )
-    else:
-        comp_periodicity = comp_periodicity
     # cf Methods.Machine.LamHole.set_pole_pair_number
     if isinstance(set_pole_pair_number, ImportError):
         set_pole_pair_number = property(
@@ -223,6 +212,15 @@ class LamHole(Lamination):
         )
     else:
         set_pole_pair_number = set_pole_pair_number
+    # cf Methods.Machine.LamHole.get_Zs
+    if isinstance(get_Zs, ImportError):
+        get_Zs = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use LamHole method get_Zs: " + str(get_Zs))
+            )
+        )
+    else:
+        get_Zs = get_Zs
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -243,6 +241,7 @@ class LamHole(Lamination):
         is_stator=True,
         axial_vent=-1,
         notch=-1,
+        skew=None,
         yoke_notch=-1,
         bore=None,
         init_dict=None,
@@ -287,6 +286,8 @@ class LamHole(Lamination):
                 axial_vent = init_dict["axial_vent"]
             if "notch" in list(init_dict.keys()):
                 notch = init_dict["notch"]
+            if "skew" in list(init_dict.keys()):
+                skew = init_dict["skew"]
             if "yoke_notch" in list(init_dict.keys()):
                 yoke_notch = init_dict["yoke_notch"]
             if "bore" in list(init_dict.keys()):
@@ -306,6 +307,7 @@ class LamHole(Lamination):
             is_stator=is_stator,
             axial_vent=axial_vent,
             notch=notch,
+            skew=skew,
             yoke_notch=yoke_notch,
             bore=bore,
         )
