@@ -58,9 +58,11 @@ except ImportError as error:
     get_bore_desc = error
 
 try:
-    from ..Methods.Machine.LamSlotMulti.comp_periodicity import comp_periodicity
+    from ..Methods.Machine.LamSlotMulti.comp_periodicity_spatial import (
+        comp_periodicity_spatial,
+    )
 except ImportError as error:
-    comp_periodicity = error
+    comp_periodicity_spatial = error
 
 
 from numpy import array, array_equal
@@ -69,6 +71,7 @@ from .Slot import Slot
 from .Material import Material
 from .Hole import Hole
 from .Notch import Notch
+from .Skew import Skew
 from .Bore import Bore
 
 
@@ -163,18 +166,18 @@ class LamSlotMulti(Lamination):
         )
     else:
         get_bore_desc = get_bore_desc
-    # cf Methods.Machine.LamSlotMulti.comp_periodicity
-    if isinstance(comp_periodicity, ImportError):
-        comp_periodicity = property(
+    # cf Methods.Machine.LamSlotMulti.comp_periodicity_spatial
+    if isinstance(comp_periodicity_spatial, ImportError):
+        comp_periodicity_spatial = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use LamSlotMulti method comp_periodicity: "
-                    + str(comp_periodicity)
+                    "Can't use LamSlotMulti method comp_periodicity_spatial: "
+                    + str(comp_periodicity_spatial)
                 )
             )
         )
     else:
-        comp_periodicity = comp_periodicity
+        comp_periodicity_spatial = comp_periodicity_spatial
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -197,6 +200,7 @@ class LamSlotMulti(Lamination):
         is_stator=True,
         axial_vent=-1,
         notch=-1,
+        skew=None,
         yoke_notch=-1,
         bore=None,
         init_dict=None,
@@ -245,6 +249,8 @@ class LamSlotMulti(Lamination):
                 axial_vent = init_dict["axial_vent"]
             if "notch" in list(init_dict.keys()):
                 notch = init_dict["notch"]
+            if "skew" in list(init_dict.keys()):
+                skew = init_dict["skew"]
             if "yoke_notch" in list(init_dict.keys()):
                 yoke_notch = init_dict["yoke_notch"]
             if "bore" in list(init_dict.keys()):
@@ -266,6 +272,7 @@ class LamSlotMulti(Lamination):
             is_stator=is_stator,
             axial_vent=axial_vent,
             notch=notch,
+            skew=skew,
             yoke_notch=yoke_notch,
             bore=bore,
         )
