@@ -98,9 +98,9 @@ except ImportError as error:
     comp_mmf_unit = error
 
 try:
-    from ..Methods.Machine.LamSlotWind.comp_rot_dir import comp_rot_dir
+    from ..Methods.Machine.LamSlotWind.comp_mmf_dir import comp_mmf_dir
 except ImportError as error:
-    comp_rot_dir = error
+    comp_mmf_dir = error
 
 try:
     from ..Methods.Machine.LamSlotWind.comp_lengths_winding import comp_lengths_winding
@@ -113,9 +113,11 @@ except ImportError as error:
     comp_number_phase_eq = error
 
 try:
-    from ..Methods.Machine.LamSlotWind.comp_periodicity import comp_periodicity
+    from ..Methods.Machine.LamSlotWind.comp_periodicity_spatial import (
+        comp_periodicity_spatial,
+    )
 except ImportError as error:
-    comp_periodicity = error
+    comp_periodicity_spatial = error
 
 try:
     from ..Methods.Machine.LamSlotWind.set_pole_pair_number import set_pole_pair_number
@@ -129,6 +131,7 @@ from .Slot import Slot
 from .Material import Material
 from .Hole import Hole
 from .Notch import Notch
+from .Skew import Skew
 from .Bore import Bore
 
 
@@ -317,17 +320,17 @@ class LamSlotWind(LamSlot):
         )
     else:
         comp_mmf_unit = comp_mmf_unit
-    # cf Methods.Machine.LamSlotWind.comp_rot_dir
-    if isinstance(comp_rot_dir, ImportError):
-        comp_rot_dir = property(
+    # cf Methods.Machine.LamSlotWind.comp_mmf_dir
+    if isinstance(comp_mmf_dir, ImportError):
+        comp_mmf_dir = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use LamSlotWind method comp_rot_dir: " + str(comp_rot_dir)
+                    "Can't use LamSlotWind method comp_mmf_dir: " + str(comp_mmf_dir)
                 )
             )
         )
     else:
-        comp_rot_dir = comp_rot_dir
+        comp_mmf_dir = comp_mmf_dir
     # cf Methods.Machine.LamSlotWind.comp_lengths_winding
     if isinstance(comp_lengths_winding, ImportError):
         comp_lengths_winding = property(
@@ -352,18 +355,18 @@ class LamSlotWind(LamSlot):
         )
     else:
         comp_number_phase_eq = comp_number_phase_eq
-    # cf Methods.Machine.LamSlotWind.comp_periodicity
-    if isinstance(comp_periodicity, ImportError):
-        comp_periodicity = property(
+    # cf Methods.Machine.LamSlotWind.comp_periodicity_spatial
+    if isinstance(comp_periodicity_spatial, ImportError):
+        comp_periodicity_spatial = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use LamSlotWind method comp_periodicity: "
-                    + str(comp_periodicity)
+                    "Can't use LamSlotWind method comp_periodicity_spatial: "
+                    + str(comp_periodicity_spatial)
                 )
             )
         )
     else:
-        comp_periodicity = comp_periodicity
+        comp_periodicity_spatial = comp_periodicity_spatial
     # cf Methods.Machine.LamSlotWind.set_pole_pair_number
     if isinstance(set_pole_pair_number, ImportError):
         set_pole_pair_number = property(
@@ -398,6 +401,7 @@ class LamSlotWind(LamSlot):
         is_stator=True,
         axial_vent=-1,
         notch=-1,
+        skew=None,
         yoke_notch=-1,
         bore=None,
         init_dict=None,
@@ -446,6 +450,8 @@ class LamSlotWind(LamSlot):
                 axial_vent = init_dict["axial_vent"]
             if "notch" in list(init_dict.keys()):
                 notch = init_dict["notch"]
+            if "skew" in list(init_dict.keys()):
+                skew = init_dict["skew"]
             if "yoke_notch" in list(init_dict.keys()):
                 yoke_notch = init_dict["yoke_notch"]
             if "bore" in list(init_dict.keys()):
@@ -467,6 +473,7 @@ class LamSlotWind(LamSlot):
             is_stator=is_stator,
             axial_vent=axial_vent,
             notch=notch,
+            skew=skew,
             yoke_notch=yoke_notch,
             bore=bore,
         )
