@@ -44,11 +44,6 @@ try:
 except ImportError as error:
     comp_number_phase_eq = error
 
-try:
-    from ..Methods.Machine.LamSquirrelCage.comp_periodicity import comp_periodicity
-except ImportError as error:
-    comp_periodicity = error
-
 try:
     from ..Methods.Machine.LamSquirrelCage.comp_surface_ring import comp_surface_ring
 except ImportError as error:
@@ -68,6 +63,7 @@ from .Winding import Winding
 from .Slot import Slot
 from .Hole import Hole
 from .Notch import Notch
+from .Skew import Skew
 from .Bore import Bore
 
 
@@ -131,18 +127,6 @@ class LamSquirrelCage(LamSlotWind):
         )
     else:
         comp_number_phase_eq = comp_number_phase_eq
-    # cf Methods.Machine.LamSquirrelCage.comp_periodicity
-    if isinstance(comp_periodicity, ImportError):
-        comp_periodicity = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use LamSquirrelCage method comp_periodicity: "
-                    + str(comp_periodicity)
-                )
-            )
-        )
-    else:
-        comp_periodicity = comp_periodicity
     # cf Methods.Machine.LamSquirrelCage.comp_surface_ring
     if isinstance(comp_surface_ring, ImportError):
         comp_surface_ring = property(
@@ -192,6 +176,7 @@ class LamSquirrelCage(LamSlotWind):
         is_stator=True,
         axial_vent=-1,
         notch=-1,
+        skew=None,
         yoke_notch=-1,
         bore=None,
         init_dict=None,
@@ -246,6 +231,8 @@ class LamSquirrelCage(LamSlotWind):
                 axial_vent = init_dict["axial_vent"]
             if "notch" in list(init_dict.keys()):
                 notch = init_dict["notch"]
+            if "skew" in list(init_dict.keys()):
+                skew = init_dict["skew"]
             if "yoke_notch" in list(init_dict.keys()):
                 yoke_notch = init_dict["yoke_notch"]
             if "bore" in list(init_dict.keys()):
@@ -270,6 +257,7 @@ class LamSquirrelCage(LamSlotWind):
             is_stator=is_stator,
             axial_vent=axial_vent,
             notch=notch,
+            skew=skew,
             yoke_notch=yoke_notch,
             bore=bore,
         )
