@@ -134,6 +134,13 @@ try:
 except ImportError as error:
     comp_point_ref = error
 
+try:
+    from ..Methods.Machine.Lamination.comp_periodicity_spatial import (
+        comp_periodicity_spatial,
+    )
+except ImportError as error:
+    comp_periodicity_spatial = error
+
 try:
     from ..Methods.Machine.Lamination.get_label import get_label
 except ImportError as error:
@@ -144,11 +151,24 @@ try:
 except ImportError as error:
     get_yoke_side_line = error
 
+try:
+    from ..Methods.Machine.Lamination.get_notches_surf import get_notches_surf
+except ImportError as error:
+    get_notches_surf = error
+
+try:
+    from ..Methods.Machine.Lamination.comp_periodicity_duct_spatial import (
+        comp_periodicity_duct_spatial,
+    )
+except ImportError as error:
+    comp_periodicity_duct_spatial = error
+
 
 from ._check import InitUnKnowClassError
 from .Material import Material
 from .Hole import Hole
 from .Notch import Notch
+from .Skew import Skew
 from .Bore import Bore
 
 
@@ -409,6 +429,18 @@ class Lamination(FrozenClass):
         )
     else:
         comp_point_ref = comp_point_ref
+    # cf Methods.Machine.Lamination.comp_periodicity_spatial
+    if isinstance(comp_periodicity_spatial, ImportError):
+        comp_periodicity_spatial = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Lamination method comp_periodicity_spatial: "
+                    + str(comp_periodicity_spatial)
+                )
+            )
+        )
+    else:
+        comp_periodicity_spatial = comp_periodicity_spatial
     # cf Methods.Machine.Lamination.get_label
     if isinstance(get_label, ImportError):
         get_label = property(
@@ -430,6 +462,30 @@ class Lamination(FrozenClass):
         )
     else:
         get_yoke_side_line = get_yoke_side_line
+    # cf Methods.Machine.Lamination.get_notches_surf
+    if isinstance(get_notches_surf, ImportError):
+        get_notches_surf = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Lamination method get_notches_surf: "
+                    + str(get_notches_surf)
+                )
+            )
+        )
+    else:
+        get_notches_surf = get_notches_surf
+    # cf Methods.Machine.Lamination.comp_periodicity_duct_spatial
+    if isinstance(comp_periodicity_duct_spatial, ImportError):
+        comp_periodicity_duct_spatial = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Lamination method comp_periodicity_duct_spatial: "
+                    + str(comp_periodicity_duct_spatial)
+                )
+            )
+        )
+    else:
+        comp_periodicity_duct_spatial = comp_periodicity_duct_spatial
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -449,6 +505,7 @@ class Lamination(FrozenClass):
         is_stator=True,
         axial_vent=-1,
         notch=-1,
+        skew=None,
         yoke_notch=-1,
         bore=None,
         init_dict=None,
@@ -491,6 +548,8 @@ class Lamination(FrozenClass):
                 axial_vent = init_dict["axial_vent"]
             if "notch" in list(init_dict.keys()):
                 notch = init_dict["notch"]
+            if "skew" in list(init_dict.keys()):
+                skew = init_dict["skew"]
             if "yoke_notch" in list(init_dict.keys()):
                 yoke_notch = init_dict["yoke_notch"]
             if "bore" in list(init_dict.keys()):
@@ -508,6 +567,7 @@ class Lamination(FrozenClass):
         self.is_stator = is_stator
         self.axial_vent = axial_vent
         self.notch = notch
+        self.skew = skew
         self.yoke_notch = yoke_notch
         self.bore = bore
 
@@ -547,6 +607,11 @@ class Lamination(FrozenClass):
         for ii in range(len(self.notch)):
             tmp = self.notch[ii].__str__().replace(linesep, linesep + "\t") + linesep
             Lamination_str += "notch[" + str(ii) + "] =" + tmp + linesep + linesep
+        if self.skew is not None:
+            tmp = self.skew.__str__().replace(linesep, linesep + "\t").rstrip("\t")
+            Lamination_str += "skew = " + tmp
+        else:
+            Lamination_str += "skew = None" + linesep + linesep
         if len(self.yoke_notch) == 0:
             Lamination_str += "yoke_notch = []" + linesep
         for ii in range(len(self.yoke_notch)):
@@ -588,6 +653,8 @@ class Lamination(FrozenClass):
             return False
         if other.notch != self.notch:
             return False
+        if other.skew != self.skew:
+            return False
         if other.yoke_notch != self.yoke_notch:
             return False
         if other.bore != self.bore:
@@ -656,6 +723,12 @@ class Lamination(FrozenClass):
                         other.notch[ii], name=name + ".notch[" + str(ii) + "]"
                     )
                 )
+        if (other.skew is None and self.skew is not None) or (
+            other.skew is not None and self.skew is None
+        ):
+            diff_list.append(name + ".skew None mismatch")
+        elif self.skew is not None:
+            diff_list.extend(self.skew.compare(other.skew, name=name + ".skew"))
         if (other.yoke_notch is None and self.yoke_notch is not None) or (
             other.yoke_notch is not None and self.yoke_notch is None
         ):
@@ -700,6 +773,7 @@ class Lamination(FrozenClass):
         if self.notch is not None:
             for value in self.notch:
                 S += getsizeof(value)
+        S += getsizeof(self.skew)
         if self.yoke_notch is not None:
             for value in self.yoke_notch:
                 S += getsizeof(value)
@@ -764,6 +838,14 @@ class Lamination(FrozenClass):
                     )
                 else:
                     Lamination_dict["notch"].append(None)
+        if self.skew is None:
+            Lamination_dict["skew"] = None
+        else:
+            Lamination_dict["skew"] = self.skew.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         if self.yoke_notch is None:
             Lamination_dict["yoke_notch"] = None
         else:
@@ -806,6 +888,8 @@ class Lamination(FrozenClass):
         self.is_stator = None
         self.axial_vent = None
         self.notch = None
+        if self.skew is not None:
+            self.skew._set_None()
         self.yoke_notch = None
         if self.bore is not None:
             self.bore._set_None()
@@ -1057,6 +1141,34 @@ class Lamination(FrozenClass):
         """,
     )
 
+    def _get_skew(self):
+        """getter of skew"""
+        return self._skew
+
+    def _set_skew(self, value):
+        """setter of skew"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class("pyleecan.Classes", value.get("__class__"), "skew")
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = Skew()
+        check_var("skew", value, "Skew")
+        self._skew = value
+
+        if self._skew is not None:
+            self._skew.parent = self
+
+    skew = property(
+        fget=_get_skew,
+        fset=_set_skew,
+        doc=u"""Skew object
+
+        :Type: Skew
+        """,
+    )
+
     def _get_yoke_notch(self):
         """getter of yoke_notch"""
         if self._yoke_notch is not None:
