@@ -197,23 +197,39 @@ class MachineDFIM(MachineAsync):
         S += getsizeof(self.stator)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from MachineAsync
-        MachineDFIM_dict = super(MachineDFIM, self).as_dict(**kwargs)
+        MachineDFIM_dict = super(MachineDFIM, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         if self.rotor is None:
             MachineDFIM_dict["rotor"] = None
         else:
-            MachineDFIM_dict["rotor"] = self.rotor.as_dict(**kwargs)
+            MachineDFIM_dict["rotor"] = self.rotor.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         if self.stator is None:
             MachineDFIM_dict["stator"] = None
         else:
-            MachineDFIM_dict["stator"] = self.stator.as_dict(**kwargs)
+            MachineDFIM_dict["stator"] = self.stator.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         MachineDFIM_dict["__class__"] = "MachineDFIM"
