@@ -201,22 +201,36 @@ class MachineUD(Machine):
         S += getsizeof(self.is_sync)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Machine
-        MachineUD_dict = super(MachineUD, self).as_dict(**kwargs)
+        MachineUD_dict = super(MachineUD, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         if self.lam_list is None:
             MachineUD_dict["lam_list"] = None
         else:
             MachineUD_dict["lam_list"] = list()
             for obj in self.lam_list:
                 if obj is not None:
-                    MachineUD_dict["lam_list"].append(obj.as_dict(**kwargs))
+                    MachineUD_dict["lam_list"].append(
+                        obj.as_dict(
+                            type_handle_ndarray=type_handle_ndarray,
+                            keep_function=keep_function,
+                            **kwargs
+                        )
+                    )
                 else:
                     MachineUD_dict["lam_list"].append(None)
         MachineUD_dict["is_sync"] = self.is_sync
