@@ -42,11 +42,6 @@ try:
 except ImportError as error:
     get_path_save = error
 
-try:
-    from ..Methods.Simulation.MagElmer.comp_axes import comp_axes
-except ImportError as error:
-    comp_axes = error
-
 try:
     from ..Methods.Simulation.MagElmer.gen_elmer_mesh import gen_elmer_mesh
 except ImportError as error:
@@ -55,6 +50,7 @@ except ImportError as error:
 
 from ._check import InitUnKnowClassError
 from .DXFImport import DXFImport
+from .SliceModel import SliceModel
 
 
 class MagElmer(Magnetics):
@@ -119,15 +115,6 @@ class MagElmer(Magnetics):
         )
     else:
         get_path_save = get_path_save
-    # cf Methods.Simulation.MagElmer.comp_axes
-    if isinstance(comp_axes, ImportError):
-        comp_axes = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use MagElmer method comp_axes: " + str(comp_axes))
-            )
-        )
-    else:
-        comp_axes = comp_axes
     # cf Methods.Simulation.MagElmer.gen_elmer_mesh
     if isinstance(gen_elmer_mesh, ImportError):
         gen_elmer_mesh = property(
@@ -160,7 +147,8 @@ class MagElmer(Magnetics):
         nb_worker=1,
         is_remove_slotS=False,
         is_remove_slotR=False,
-        is_remove_vent=False,
+        is_remove_ventS=False,
+        is_remove_ventR=False,
         is_mmfs=True,
         is_mmfr=True,
         type_BH_stator=0,
@@ -170,6 +158,10 @@ class MagElmer(Magnetics):
         angle_stator_shift=0,
         angle_rotor_shift=0,
         logger_name="Pyleecan.Magnetics",
+        Slice_enforced=None,
+        Nslices_enforced=None,
+        type_distribution_enforced=None,
+        is_current_harm=True,
         init_dict=None,
         init_str=None,
     ):
@@ -214,8 +206,10 @@ class MagElmer(Magnetics):
                 is_remove_slotS = init_dict["is_remove_slotS"]
             if "is_remove_slotR" in list(init_dict.keys()):
                 is_remove_slotR = init_dict["is_remove_slotR"]
-            if "is_remove_vent" in list(init_dict.keys()):
-                is_remove_vent = init_dict["is_remove_vent"]
+            if "is_remove_ventS" in list(init_dict.keys()):
+                is_remove_ventS = init_dict["is_remove_ventS"]
+            if "is_remove_ventR" in list(init_dict.keys()):
+                is_remove_ventR = init_dict["is_remove_ventR"]
             if "is_mmfs" in list(init_dict.keys()):
                 is_mmfs = init_dict["is_mmfs"]
             if "is_mmfr" in list(init_dict.keys()):
@@ -234,6 +228,14 @@ class MagElmer(Magnetics):
                 angle_rotor_shift = init_dict["angle_rotor_shift"]
             if "logger_name" in list(init_dict.keys()):
                 logger_name = init_dict["logger_name"]
+            if "Slice_enforced" in list(init_dict.keys()):
+                Slice_enforced = init_dict["Slice_enforced"]
+            if "Nslices_enforced" in list(init_dict.keys()):
+                Nslices_enforced = init_dict["Nslices_enforced"]
+            if "type_distribution_enforced" in list(init_dict.keys()):
+                type_distribution_enforced = init_dict["type_distribution_enforced"]
+            if "is_current_harm" in list(init_dict.keys()):
+                is_current_harm = init_dict["is_current_harm"]
         # Set the properties (value check and convertion are done in setter)
         self.Kmesh_fineness = Kmesh_fineness
         self.Kgeo_fineness = Kgeo_fineness
@@ -250,7 +252,8 @@ class MagElmer(Magnetics):
         super(MagElmer, self).__init__(
             is_remove_slotS=is_remove_slotS,
             is_remove_slotR=is_remove_slotR,
-            is_remove_vent=is_remove_vent,
+            is_remove_ventS=is_remove_ventS,
+            is_remove_ventR=is_remove_ventR,
             is_mmfs=is_mmfs,
             is_mmfr=is_mmfr,
             type_BH_stator=type_BH_stator,
@@ -260,6 +263,10 @@ class MagElmer(Magnetics):
             angle_stator_shift=angle_stator_shift,
             angle_rotor_shift=angle_rotor_shift,
             logger_name=logger_name,
+            Slice_enforced=Slice_enforced,
+            Nslices_enforced=Nslices_enforced,
+            type_distribution_enforced=type_distribution_enforced,
+            is_current_harm=is_current_harm,
         )
         # The class is frozen (in Magnetics init), for now it's impossible to
         # add new properties
