@@ -27,8 +27,19 @@ try:
 except ImportError as error:
     comp_axes = error
 
+try:
+    from ..Methods.Simulation.Magnetics.get_slice_model import get_slice_model
+except ImportError as error:
+    get_slice_model = error
+
+try:
+    from ..Methods.Simulation.Magnetics.comp_I_mag import comp_I_mag
+except ImportError as error:
+    comp_I_mag = error
+
 
 from ._check import InitUnKnowClassError
+from .SliceModel import SliceModel
 
 
 class Magnetics(FrozenClass):
@@ -55,6 +66,27 @@ class Magnetics(FrozenClass):
         )
     else:
         comp_axes = comp_axes
+    # cf Methods.Simulation.Magnetics.get_slice_model
+    if isinstance(get_slice_model, ImportError):
+        get_slice_model = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Magnetics method get_slice_model: "
+                    + str(get_slice_model)
+                )
+            )
+        )
+    else:
+        get_slice_model = get_slice_model
+    # cf Methods.Simulation.Magnetics.comp_I_mag
+    if isinstance(comp_I_mag, ImportError):
+        comp_I_mag = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use Magnetics method comp_I_mag: " + str(comp_I_mag))
+            )
+        )
+    else:
+        comp_I_mag = comp_I_mag
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -65,7 +97,8 @@ class Magnetics(FrozenClass):
         self,
         is_remove_slotS=False,
         is_remove_slotR=False,
-        is_remove_vent=False,
+        is_remove_ventS=False,
+        is_remove_ventR=False,
         is_mmfs=True,
         is_mmfr=True,
         type_BH_stator=0,
@@ -75,6 +108,10 @@ class Magnetics(FrozenClass):
         angle_stator_shift=0,
         angle_rotor_shift=0,
         logger_name="Pyleecan.Magnetics",
+        Slice_enforced=None,
+        Nslices_enforced=None,
+        type_distribution_enforced=None,
+        is_current_harm=True,
         init_dict=None,
         init_str=None,
     ):
@@ -97,8 +134,10 @@ class Magnetics(FrozenClass):
                 is_remove_slotS = init_dict["is_remove_slotS"]
             if "is_remove_slotR" in list(init_dict.keys()):
                 is_remove_slotR = init_dict["is_remove_slotR"]
-            if "is_remove_vent" in list(init_dict.keys()):
-                is_remove_vent = init_dict["is_remove_vent"]
+            if "is_remove_ventS" in list(init_dict.keys()):
+                is_remove_ventS = init_dict["is_remove_ventS"]
+            if "is_remove_ventR" in list(init_dict.keys()):
+                is_remove_ventR = init_dict["is_remove_ventR"]
             if "is_mmfs" in list(init_dict.keys()):
                 is_mmfs = init_dict["is_mmfs"]
             if "is_mmfr" in list(init_dict.keys()):
@@ -117,11 +156,20 @@ class Magnetics(FrozenClass):
                 angle_rotor_shift = init_dict["angle_rotor_shift"]
             if "logger_name" in list(init_dict.keys()):
                 logger_name = init_dict["logger_name"]
+            if "Slice_enforced" in list(init_dict.keys()):
+                Slice_enforced = init_dict["Slice_enforced"]
+            if "Nslices_enforced" in list(init_dict.keys()):
+                Nslices_enforced = init_dict["Nslices_enforced"]
+            if "type_distribution_enforced" in list(init_dict.keys()):
+                type_distribution_enforced = init_dict["type_distribution_enforced"]
+            if "is_current_harm" in list(init_dict.keys()):
+                is_current_harm = init_dict["is_current_harm"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.is_remove_slotS = is_remove_slotS
         self.is_remove_slotR = is_remove_slotR
-        self.is_remove_vent = is_remove_vent
+        self.is_remove_ventS = is_remove_ventS
+        self.is_remove_ventR = is_remove_ventR
         self.is_mmfs = is_mmfs
         self.is_mmfr = is_mmfr
         self.type_BH_stator = type_BH_stator
@@ -131,6 +179,10 @@ class Magnetics(FrozenClass):
         self.angle_stator_shift = angle_stator_shift
         self.angle_rotor_shift = angle_rotor_shift
         self.logger_name = logger_name
+        self.Slice_enforced = Slice_enforced
+        self.Nslices_enforced = Nslices_enforced
+        self.type_distribution_enforced = type_distribution_enforced
+        self.is_current_harm = is_current_harm
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -145,7 +197,8 @@ class Magnetics(FrozenClass):
             Magnetics_str += "parent = " + str(type(self.parent)) + " object" + linesep
         Magnetics_str += "is_remove_slotS = " + str(self.is_remove_slotS) + linesep
         Magnetics_str += "is_remove_slotR = " + str(self.is_remove_slotR) + linesep
-        Magnetics_str += "is_remove_vent = " + str(self.is_remove_vent) + linesep
+        Magnetics_str += "is_remove_ventS = " + str(self.is_remove_ventS) + linesep
+        Magnetics_str += "is_remove_ventR = " + str(self.is_remove_ventR) + linesep
         Magnetics_str += "is_mmfs = " + str(self.is_mmfs) + linesep
         Magnetics_str += "is_mmfr = " + str(self.is_mmfr) + linesep
         Magnetics_str += "type_BH_stator = " + str(self.type_BH_stator) + linesep
@@ -157,6 +210,23 @@ class Magnetics(FrozenClass):
         )
         Magnetics_str += "angle_rotor_shift = " + str(self.angle_rotor_shift) + linesep
         Magnetics_str += 'logger_name = "' + str(self.logger_name) + '"' + linesep
+        if self.Slice_enforced is not None:
+            tmp = (
+                self.Slice_enforced.__str__()
+                .replace(linesep, linesep + "\t")
+                .rstrip("\t")
+            )
+            Magnetics_str += "Slice_enforced = " + tmp
+        else:
+            Magnetics_str += "Slice_enforced = None" + linesep + linesep
+        Magnetics_str += "Nslices_enforced = " + str(self.Nslices_enforced) + linesep
+        Magnetics_str += (
+            'type_distribution_enforced = "'
+            + str(self.type_distribution_enforced)
+            + '"'
+            + linesep
+        )
+        Magnetics_str += "is_current_harm = " + str(self.is_current_harm) + linesep
         return Magnetics_str
 
     def __eq__(self, other):
@@ -168,7 +238,9 @@ class Magnetics(FrozenClass):
             return False
         if other.is_remove_slotR != self.is_remove_slotR:
             return False
-        if other.is_remove_vent != self.is_remove_vent:
+        if other.is_remove_ventS != self.is_remove_ventS:
+            return False
+        if other.is_remove_ventR != self.is_remove_ventR:
             return False
         if other.is_mmfs != self.is_mmfs:
             return False
@@ -188,6 +260,14 @@ class Magnetics(FrozenClass):
             return False
         if other.logger_name != self.logger_name:
             return False
+        if other.Slice_enforced != self.Slice_enforced:
+            return False
+        if other.Nslices_enforced != self.Nslices_enforced:
+            return False
+        if other.type_distribution_enforced != self.type_distribution_enforced:
+            return False
+        if other.is_current_harm != self.is_current_harm:
+            return False
         return True
 
     def compare(self, other, name="self", ignore_list=None):
@@ -202,8 +282,10 @@ class Magnetics(FrozenClass):
             diff_list.append(name + ".is_remove_slotS")
         if other._is_remove_slotR != self._is_remove_slotR:
             diff_list.append(name + ".is_remove_slotR")
-        if other._is_remove_vent != self._is_remove_vent:
-            diff_list.append(name + ".is_remove_vent")
+        if other._is_remove_ventS != self._is_remove_ventS:
+            diff_list.append(name + ".is_remove_ventS")
+        if other._is_remove_ventR != self._is_remove_ventR:
+            diff_list.append(name + ".is_remove_ventR")
         if other._is_mmfs != self._is_mmfs:
             diff_list.append(name + ".is_mmfs")
         if other._is_mmfr != self._is_mmfr:
@@ -222,6 +304,22 @@ class Magnetics(FrozenClass):
             diff_list.append(name + ".angle_rotor_shift")
         if other._logger_name != self._logger_name:
             diff_list.append(name + ".logger_name")
+        if (other.Slice_enforced is None and self.Slice_enforced is not None) or (
+            other.Slice_enforced is not None and self.Slice_enforced is None
+        ):
+            diff_list.append(name + ".Slice_enforced None mismatch")
+        elif self.Slice_enforced is not None:
+            diff_list.extend(
+                self.Slice_enforced.compare(
+                    other.Slice_enforced, name=name + ".Slice_enforced"
+                )
+            )
+        if other._Nslices_enforced != self._Nslices_enforced:
+            diff_list.append(name + ".Nslices_enforced")
+        if other._type_distribution_enforced != self._type_distribution_enforced:
+            diff_list.append(name + ".type_distribution_enforced")
+        if other._is_current_harm != self._is_current_harm:
+            diff_list.append(name + ".is_current_harm")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -232,7 +330,8 @@ class Magnetics(FrozenClass):
         S = 0  # Full size of the object
         S += getsizeof(self.is_remove_slotS)
         S += getsizeof(self.is_remove_slotR)
-        S += getsizeof(self.is_remove_vent)
+        S += getsizeof(self.is_remove_ventS)
+        S += getsizeof(self.is_remove_ventR)
         S += getsizeof(self.is_mmfs)
         S += getsizeof(self.is_mmfr)
         S += getsizeof(self.type_BH_stator)
@@ -242,6 +341,10 @@ class Magnetics(FrozenClass):
         S += getsizeof(self.angle_stator_shift)
         S += getsizeof(self.angle_rotor_shift)
         S += getsizeof(self.logger_name)
+        S += getsizeof(self.Slice_enforced)
+        S += getsizeof(self.Nslices_enforced)
+        S += getsizeof(self.type_distribution_enforced)
+        S += getsizeof(self.is_current_harm)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -258,7 +361,8 @@ class Magnetics(FrozenClass):
         Magnetics_dict = dict()
         Magnetics_dict["is_remove_slotS"] = self.is_remove_slotS
         Magnetics_dict["is_remove_slotR"] = self.is_remove_slotR
-        Magnetics_dict["is_remove_vent"] = self.is_remove_vent
+        Magnetics_dict["is_remove_ventS"] = self.is_remove_ventS
+        Magnetics_dict["is_remove_ventR"] = self.is_remove_ventR
         Magnetics_dict["is_mmfs"] = self.is_mmfs
         Magnetics_dict["is_mmfr"] = self.is_mmfr
         Magnetics_dict["type_BH_stator"] = self.type_BH_stator
@@ -268,6 +372,17 @@ class Magnetics(FrozenClass):
         Magnetics_dict["angle_stator_shift"] = self.angle_stator_shift
         Magnetics_dict["angle_rotor_shift"] = self.angle_rotor_shift
         Magnetics_dict["logger_name"] = self.logger_name
+        if self.Slice_enforced is None:
+            Magnetics_dict["Slice_enforced"] = None
+        else:
+            Magnetics_dict["Slice_enforced"] = self.Slice_enforced.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
+        Magnetics_dict["Nslices_enforced"] = self.Nslices_enforced
+        Magnetics_dict["type_distribution_enforced"] = self.type_distribution_enforced
+        Magnetics_dict["is_current_harm"] = self.is_current_harm
         # The class name is added to the dict for deserialisation purpose
         Magnetics_dict["__class__"] = "Magnetics"
         return Magnetics_dict
@@ -277,7 +392,8 @@ class Magnetics(FrozenClass):
 
         self.is_remove_slotS = None
         self.is_remove_slotR = None
-        self.is_remove_vent = None
+        self.is_remove_ventS = None
+        self.is_remove_ventR = None
         self.is_mmfs = None
         self.is_mmfr = None
         self.type_BH_stator = None
@@ -287,6 +403,11 @@ class Magnetics(FrozenClass):
         self.angle_stator_shift = None
         self.angle_rotor_shift = None
         self.logger_name = None
+        if self.Slice_enforced is not None:
+            self.Slice_enforced._set_None()
+        self.Nslices_enforced = None
+        self.type_distribution_enforced = None
+        self.is_current_harm = None
 
     def _get_is_remove_slotS(self):
         """getter of is_remove_slotS"""
@@ -324,19 +445,37 @@ class Magnetics(FrozenClass):
         """,
     )
 
-    def _get_is_remove_vent(self):
-        """getter of is_remove_vent"""
-        return self._is_remove_vent
+    def _get_is_remove_ventS(self):
+        """getter of is_remove_ventS"""
+        return self._is_remove_ventS
 
-    def _set_is_remove_vent(self, value):
-        """setter of is_remove_vent"""
-        check_var("is_remove_vent", value, "bool")
-        self._is_remove_vent = value
+    def _set_is_remove_ventS(self, value):
+        """setter of is_remove_ventS"""
+        check_var("is_remove_ventS", value, "bool")
+        self._is_remove_ventS = value
 
-    is_remove_vent = property(
-        fget=_get_is_remove_vent,
-        fset=_set_is_remove_vent,
-        doc=u"""1 to artificially remove the ventilations duct
+    is_remove_ventS = property(
+        fget=_get_is_remove_ventS,
+        fset=_set_is_remove_ventS,
+        doc=u"""1 to artificially remove the ventilations duct of the stator
+
+        :Type: bool
+        """,
+    )
+
+    def _get_is_remove_ventR(self):
+        """getter of is_remove_ventR"""
+        return self._is_remove_ventR
+
+    def _set_is_remove_ventR(self, value):
+        """setter of is_remove_ventR"""
+        check_var("is_remove_ventR", value, "bool")
+        self._is_remove_ventR = value
+
+    is_remove_ventR = property(
+        fget=_get_is_remove_ventR,
+        fset=_set_is_remove_ventR,
+        doc=u"""1 to artificially remove the ventilations duct of the rotor
 
         :Type: bool
         """,
@@ -430,7 +569,7 @@ class Magnetics(FrozenClass):
     is_periodicity_t = property(
         fget=_get_is_periodicity_t,
         fset=_set_is_periodicity_t,
-        doc=u"""True to compute only on one time periodicity (use periodicities defined in output.mag.Time)
+        doc=u"""True to compute only on one time periodicity (use periodicities defined in axes_dict[time])
 
         :Type: bool
         """,
@@ -448,7 +587,7 @@ class Magnetics(FrozenClass):
     is_periodicity_a = property(
         fget=_get_is_periodicity_a,
         fset=_set_is_periodicity_a,
-        doc=u"""True to compute only on one angle periodicity (use periodicities defined in output.mag.Angle)
+        doc=u"""True to compute only on one angle periodicity (use periodicities defined in axes_dict[angle])
 
         :Type: bool
         """,
@@ -507,3 +646,87 @@ class Magnetics(FrozenClass):
         :Type: str
         """,
     )
+
+    def _get_Slice_enforced(self):
+        """getter of Slice_enforced"""
+        return self._Slice_enforced
+
+    def _set_Slice_enforced(self, value):
+        """setter of Slice_enforced"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "pyleecan.Classes", value.get("__class__"), "Slice_enforced"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = SliceModel()
+        check_var("Slice_enforced", value, "SliceModel")
+        self._Slice_enforced = value
+
+        if self._Slice_enforced is not None:
+            self._Slice_enforced.parent = self
+
+    Slice_enforced = property(
+        fget=_get_Slice_enforced,
+        fset=_set_Slice_enforced,
+        doc=u"""Enforce slice model to account for skew
+
+        :Type: SliceModel
+        """,
+    )
+
+    def _get_Nslices_enforced(self):
+        """getter of Nslices_enforced"""
+        return self._Nslices_enforced
+
+    def _set_Nslices_enforced(self, value):
+        """setter of Nslices_enforced"""
+        check_var("Nslices_enforced", value, "int")
+        self._Nslices_enforced = value
+
+    Nslices_enforced = property(
+        fget=_get_Nslices_enforced,
+        fset=_set_Nslices_enforced,
+        doc=u"""To enforce number of slices in slice model
+
+        :Type: int
+        """,
+    )
+
+    def _get_type_distribution_enforced(self):
+        """getter of type_distribution_enforced"""
+        return self._type_distribution_enforced
+
+    def _set_type_distribution_enforced(self, value):
+        """setter of type_distribution_enforced"""
+        check_var("type_distribution_enforced", value, "str")
+        self._type_distribution_enforced = value
+
+    type_distribution_enforced = property(
+        fget=_get_type_distribution_enforced,
+        fset=_set_type_distribution_enforced,
+        doc=u"""To enforce type of slice distribution to use for rotor skew if linear and continuous ("uniform", "gauss", "user-defined")
+
+        :Type: str
+        """,
+    )
+
+    def _get_is_current_harm(self):
+        """getter of is_current_harm"""
+        return self._is_current_harm
+
+    def _set_is_current_harm(self, value):
+        """setter of is_current_harm"""
+        check_var("is_current_harm", value, "bool")
+        self._is_current_harm = value
+
+    is_current_harm = property(
+        fget=_get_is_current_harm,
+        fset=_set_is_current_harm,
+        doc=u"""0 To compute only the airgap flux from fundamental current harmonics
+
+        :Type: bool
+        """,
+    )
