@@ -401,9 +401,13 @@ class MeshSolution(FrozenClass):
         S += getsizeof(self.path)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
@@ -416,7 +420,13 @@ class MeshSolution(FrozenClass):
             MeshSolution_dict["mesh"] = list()
             for obj in self.mesh:
                 if obj is not None:
-                    MeshSolution_dict["mesh"].append(obj.as_dict(**kwargs))
+                    MeshSolution_dict["mesh"].append(
+                        obj.as_dict(
+                            type_handle_ndarray=type_handle_ndarray,
+                            keep_function=keep_function,
+                            **kwargs
+                        )
+                    )
                 else:
                     MeshSolution_dict["mesh"].append(None)
         MeshSolution_dict["is_same_mesh"] = self.is_same_mesh
@@ -426,7 +436,13 @@ class MeshSolution(FrozenClass):
             MeshSolution_dict["solution"] = list()
             for obj in self.solution:
                 if obj is not None:
-                    MeshSolution_dict["solution"].append(obj.as_dict(**kwargs))
+                    MeshSolution_dict["solution"].append(
+                        obj.as_dict(
+                            type_handle_ndarray=type_handle_ndarray,
+                            keep_function=keep_function,
+                            **kwargs
+                        )
+                    )
                 else:
                     MeshSolution_dict["solution"].append(None)
         MeshSolution_dict["group"] = (
