@@ -228,15 +228,23 @@ class Mode(SolutionMat):
         S += getsizeof(self.order_long)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from SolutionMat
-        Mode_dict = super(Mode, self).as_dict(**kwargs)
+        Mode_dict = super(Mode, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         Mode_dict["nat_freq"] = self.nat_freq
         Mode_dict["order_circ"] = self.order_circ
         Mode_dict["order_long"] = self.order_long
