@@ -7,7 +7,7 @@
 from os import linesep
 from sys import getsizeof
 from logging import getLogger
-from ._check import set_array, check_var, raise_
+from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
 from ..Functions.copy import copy
@@ -18,29 +18,44 @@ from ._frozen import FrozenClass
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
 try:
-    from ..Methods.Output.OutElec.get_Nr import get_Nr
+    from ..Methods.Output.OutElec.get_I_fund import get_I_fund
 except ImportError as error:
-    get_Nr = error
+    get_I_fund = error
+
+try:
+    from ..Methods.Output.OutElec.get_I_harm import get_I_harm
+except ImportError as error:
+    get_I_harm = error
 
 try:
     from ..Methods.Output.OutElec.get_Is import get_Is
 except ImportError as error:
     get_Is = error
 
+try:
+    from ..Methods.Output.OutElec.get_Nr import get_Nr
+except ImportError as error:
+    get_Nr = error
+
 try:
     from ..Methods.Output.OutElec.get_Us import get_Us
 except ImportError as error:
     get_Us = error
 
 try:
-    from ..Methods.Output.OutElec.comp_I_mag import comp_I_mag
+    from ..Methods.Output.OutElec.get_Us_harm import get_Us_harm
 except ImportError as error:
-    comp_I_mag = error
+    get_Us_harm = error
+
+try:
+    from ..Methods.Output.OutElec.store import store
+except ImportError as error:
+    store = error
 
 
-from numpy import array, array_equal
 from ._check import InitUnKnowClassError
 from .OutInternal import OutInternal
+from .OP import OP
 
 
 class OutElec(FrozenClass):
@@ -49,15 +64,24 @@ class OutElec(FrozenClass):
     VERSION = 1
 
     # Check ImportError to remove unnecessary dependencies in unused method
-    # cf Methods.Output.OutElec.get_Nr
-    if isinstance(get_Nr, ImportError):
-        get_Nr = property(
+    # cf Methods.Output.OutElec.get_I_fund
+    if isinstance(get_I_fund, ImportError):
+        get_I_fund = property(
             fget=lambda x: raise_(
-                ImportError("Can't use OutElec method get_Nr: " + str(get_Nr))
+                ImportError("Can't use OutElec method get_I_fund: " + str(get_I_fund))
             )
         )
     else:
-        get_Nr = get_Nr
+        get_I_fund = get_I_fund
+    # cf Methods.Output.OutElec.get_I_harm
+    if isinstance(get_I_harm, ImportError):
+        get_I_harm = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use OutElec method get_I_harm: " + str(get_I_harm))
+            )
+        )
+    else:
+        get_I_harm = get_I_harm
     # cf Methods.Output.OutElec.get_Is
     if isinstance(get_Is, ImportError):
         get_Is = property(
@@ -67,6 +91,15 @@ class OutElec(FrozenClass):
         )
     else:
         get_Is = get_Is
+    # cf Methods.Output.OutElec.get_Nr
+    if isinstance(get_Nr, ImportError):
+        get_Nr = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use OutElec method get_Nr: " + str(get_Nr))
+            )
+        )
+    else:
+        get_Nr = get_Nr
     # cf Methods.Output.OutElec.get_Us
     if isinstance(get_Us, ImportError):
         get_Us = property(
@@ -76,15 +109,24 @@ class OutElec(FrozenClass):
         )
     else:
         get_Us = get_Us
-    # cf Methods.Output.OutElec.comp_I_mag
-    if isinstance(comp_I_mag, ImportError):
-        comp_I_mag = property(
+    # cf Methods.Output.OutElec.get_Us_harm
+    if isinstance(get_Us_harm, ImportError):
+        get_Us_harm = property(
             fget=lambda x: raise_(
-                ImportError("Can't use OutElec method comp_I_mag: " + str(comp_I_mag))
+                ImportError("Can't use OutElec method get_Us_harm: " + str(get_Us_harm))
             )
         )
     else:
-        comp_I_mag = comp_I_mag
+        get_Us_harm = get_Us_harm
+    # cf Methods.Output.OutElec.store
+    if isinstance(store, ImportError):
+        store = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use OutElec method store: " + str(store))
+            )
+        )
+    else:
+        store = store
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -93,24 +135,20 @@ class OutElec(FrozenClass):
 
     def __init__(
         self,
-        Time=None,
-        Angle=None,
+        axes_dict=None,
         Is=None,
         Ir=None,
-        angle_rotor=None,
-        N0=None,
-        angle_rotor_initial=0,
         logger_name="Pyleecan.Electrical",
-        Tem_av_ref=None,
-        Id_ref=None,
-        Iq_ref=None,
-        felec=None,
-        Ud_ref=None,
-        Uq_ref=None,
         Pj_losses=None,
-        Pem_av_ref=None,
         Us=None,
         internal=None,
+        Us_PWM=None,
+        OP=None,
+        Pem_av_ref=None,
+        Tem_av_ref=None,
+        Is_harm=None,
+        phase_dir=None,
+        current_dir=None,
         init_dict=None,
         init_str=None,
     ):
@@ -129,62 +167,50 @@ class OutElec(FrozenClass):
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
-            if "Time" in list(init_dict.keys()):
-                Time = init_dict["Time"]
-            if "Angle" in list(init_dict.keys()):
-                Angle = init_dict["Angle"]
+            if "axes_dict" in list(init_dict.keys()):
+                axes_dict = init_dict["axes_dict"]
             if "Is" in list(init_dict.keys()):
                 Is = init_dict["Is"]
             if "Ir" in list(init_dict.keys()):
                 Ir = init_dict["Ir"]
-            if "angle_rotor" in list(init_dict.keys()):
-                angle_rotor = init_dict["angle_rotor"]
-            if "N0" in list(init_dict.keys()):
-                N0 = init_dict["N0"]
-            if "angle_rotor_initial" in list(init_dict.keys()):
-                angle_rotor_initial = init_dict["angle_rotor_initial"]
             if "logger_name" in list(init_dict.keys()):
                 logger_name = init_dict["logger_name"]
-            if "Tem_av_ref" in list(init_dict.keys()):
-                Tem_av_ref = init_dict["Tem_av_ref"]
-            if "Id_ref" in list(init_dict.keys()):
-                Id_ref = init_dict["Id_ref"]
-            if "Iq_ref" in list(init_dict.keys()):
-                Iq_ref = init_dict["Iq_ref"]
-            if "felec" in list(init_dict.keys()):
-                felec = init_dict["felec"]
-            if "Ud_ref" in list(init_dict.keys()):
-                Ud_ref = init_dict["Ud_ref"]
-            if "Uq_ref" in list(init_dict.keys()):
-                Uq_ref = init_dict["Uq_ref"]
             if "Pj_losses" in list(init_dict.keys()):
                 Pj_losses = init_dict["Pj_losses"]
-            if "Pem_av_ref" in list(init_dict.keys()):
-                Pem_av_ref = init_dict["Pem_av_ref"]
             if "Us" in list(init_dict.keys()):
                 Us = init_dict["Us"]
             if "internal" in list(init_dict.keys()):
                 internal = init_dict["internal"]
+            if "Us_PWM" in list(init_dict.keys()):
+                Us_PWM = init_dict["Us_PWM"]
+            if "OP" in list(init_dict.keys()):
+                OP = init_dict["OP"]
+            if "Pem_av_ref" in list(init_dict.keys()):
+                Pem_av_ref = init_dict["Pem_av_ref"]
+            if "Tem_av_ref" in list(init_dict.keys()):
+                Tem_av_ref = init_dict["Tem_av_ref"]
+            if "Is_harm" in list(init_dict.keys()):
+                Is_harm = init_dict["Is_harm"]
+            if "phase_dir" in list(init_dict.keys()):
+                phase_dir = init_dict["phase_dir"]
+            if "current_dir" in list(init_dict.keys()):
+                current_dir = init_dict["current_dir"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
-        self.Time = Time
-        self.Angle = Angle
+        self.axes_dict = axes_dict
         self.Is = Is
         self.Ir = Ir
-        self.angle_rotor = angle_rotor
-        self.N0 = N0
-        self.angle_rotor_initial = angle_rotor_initial
         self.logger_name = logger_name
-        self.Tem_av_ref = Tem_av_ref
-        self.Id_ref = Id_ref
-        self.Iq_ref = Iq_ref
-        self.felec = felec
-        self.Ud_ref = Ud_ref
-        self.Uq_ref = Uq_ref
         self.Pj_losses = Pj_losses
-        self.Pem_av_ref = Pem_av_ref
         self.Us = Us
         self.internal = internal
+        self.Us_PWM = Us_PWM
+        self.OP = OP
+        self.Pem_av_ref = Pem_av_ref
+        self.Tem_av_ref = Tem_av_ref
+        self.Is_harm = Is_harm
+        self.phase_dir = phase_dir
+        self.current_dir = current_dir
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -197,36 +223,28 @@ class OutElec(FrozenClass):
             OutElec_str += "parent = None " + linesep
         else:
             OutElec_str += "parent = " + str(type(self.parent)) + " object" + linesep
-        OutElec_str += "Time = " + str(self.Time) + linesep + linesep
-        OutElec_str += "Angle = " + str(self.Angle) + linesep + linesep
+        OutElec_str += "axes_dict = " + str(self.axes_dict) + linesep + linesep
         OutElec_str += "Is = " + str(self.Is) + linesep + linesep
         OutElec_str += "Ir = " + str(self.Ir) + linesep + linesep
-        OutElec_str += (
-            "angle_rotor = "
-            + linesep
-            + str(self.angle_rotor).replace(linesep, linesep + "\t")
-            + linesep
-            + linesep
-        )
-        OutElec_str += "N0 = " + str(self.N0) + linesep
-        OutElec_str += (
-            "angle_rotor_initial = " + str(self.angle_rotor_initial) + linesep
-        )
         OutElec_str += 'logger_name = "' + str(self.logger_name) + '"' + linesep
-        OutElec_str += "Tem_av_ref = " + str(self.Tem_av_ref) + linesep
-        OutElec_str += "Id_ref = " + str(self.Id_ref) + linesep
-        OutElec_str += "Iq_ref = " + str(self.Iq_ref) + linesep
-        OutElec_str += "felec = " + str(self.felec) + linesep
-        OutElec_str += "Ud_ref = " + str(self.Ud_ref) + linesep
-        OutElec_str += "Uq_ref = " + str(self.Uq_ref) + linesep
         OutElec_str += "Pj_losses = " + str(self.Pj_losses) + linesep
-        OutElec_str += "Pem_av_ref = " + str(self.Pem_av_ref) + linesep
         OutElec_str += "Us = " + str(self.Us) + linesep + linesep
         if self.internal is not None:
             tmp = self.internal.__str__().replace(linesep, linesep + "\t").rstrip("\t")
             OutElec_str += "internal = " + tmp
         else:
             OutElec_str += "internal = None" + linesep + linesep
+        OutElec_str += "Us_PWM = " + str(self.Us_PWM) + linesep + linesep
+        if self.OP is not None:
+            tmp = self.OP.__str__().replace(linesep, linesep + "\t").rstrip("\t")
+            OutElec_str += "OP = " + tmp
+        else:
+            OutElec_str += "OP = None" + linesep + linesep
+        OutElec_str += "Pem_av_ref = " + str(self.Pem_av_ref) + linesep
+        OutElec_str += "Tem_av_ref = " + str(self.Tem_av_ref) + linesep
+        OutElec_str += "Is_harm = " + str(self.Is_harm) + linesep + linesep
+        OutElec_str += "phase_dir = " + str(self.phase_dir) + linesep
+        OutElec_str += "current_dir = " + str(self.current_dir) + linesep
         return OutElec_str
 
     def __eq__(self, other):
@@ -234,42 +252,34 @@ class OutElec(FrozenClass):
 
         if type(other) != type(self):
             return False
-        if other.Time != self.Time:
-            return False
-        if other.Angle != self.Angle:
+        if other.axes_dict != self.axes_dict:
             return False
         if other.Is != self.Is:
             return False
         if other.Ir != self.Ir:
             return False
-        if not array_equal(other.angle_rotor, self.angle_rotor):
-            return False
-        if other.N0 != self.N0:
-            return False
-        if other.angle_rotor_initial != self.angle_rotor_initial:
-            return False
         if other.logger_name != self.logger_name:
             return False
-        if other.Tem_av_ref != self.Tem_av_ref:
-            return False
-        if other.Id_ref != self.Id_ref:
-            return False
-        if other.Iq_ref != self.Iq_ref:
-            return False
-        if other.felec != self.felec:
-            return False
-        if other.Ud_ref != self.Ud_ref:
-            return False
-        if other.Uq_ref != self.Uq_ref:
-            return False
         if other.Pj_losses != self.Pj_losses:
             return False
-        if other.Pem_av_ref != self.Pem_av_ref:
-            return False
         if other.Us != self.Us:
             return False
         if other.internal != self.internal:
             return False
+        if other.Us_PWM != self.Us_PWM:
+            return False
+        if other.OP != self.OP:
+            return False
+        if other.Pem_av_ref != self.Pem_av_ref:
+            return False
+        if other.Tem_av_ref != self.Tem_av_ref:
+            return False
+        if other.Is_harm != self.Is_harm:
+            return False
+        if other.phase_dir != self.phase_dir:
+            return False
+        if other.current_dir != self.current_dir:
+            return False
         return True
 
     def compare(self, other, name="self", ignore_list=None):
@@ -280,18 +290,21 @@ class OutElec(FrozenClass):
         if type(other) != type(self):
             return ["type(" + name + ")"]
         diff_list = list()
-        if (other.Time is None and self.Time is not None) or (
-            other.Time is not None and self.Time is None
+        if (other.axes_dict is None and self.axes_dict is not None) or (
+            other.axes_dict is not None and self.axes_dict is None
         ):
-            diff_list.append(name + ".Time None mismatch")
-        elif self.Time is not None:
-            diff_list.extend(self.Time.compare(other.Time, name=name + ".Time"))
-        if (other.Angle is None and self.Angle is not None) or (
-            other.Angle is not None and self.Angle is None
-        ):
-            diff_list.append(name + ".Angle None mismatch")
-        elif self.Angle is not None:
-            diff_list.extend(self.Angle.compare(other.Angle, name=name + ".Angle"))
+            diff_list.append(name + ".axes_dict None mismatch")
+        elif self.axes_dict is None:
+            pass
+        elif len(other.axes_dict) != len(self.axes_dict):
+            diff_list.append("len(" + name + "axes_dict)")
+        else:
+            for key in self.axes_dict:
+                diff_list.extend(
+                    self.axes_dict[key].compare(
+                        other.axes_dict[key], name=name + ".axes_dict"
+                    )
+                )
         if (other.Is is None and self.Is is not None) or (
             other.Is is not None and self.Is is None
         ):
@@ -304,30 +317,10 @@ class OutElec(FrozenClass):
             diff_list.append(name + ".Ir None mismatch")
         elif self.Ir is not None:
             diff_list.extend(self.Ir.compare(other.Ir, name=name + ".Ir"))
-        if not array_equal(other.angle_rotor, self.angle_rotor):
-            diff_list.append(name + ".angle_rotor")
-        if other._N0 != self._N0:
-            diff_list.append(name + ".N0")
-        if other._angle_rotor_initial != self._angle_rotor_initial:
-            diff_list.append(name + ".angle_rotor_initial")
         if other._logger_name != self._logger_name:
             diff_list.append(name + ".logger_name")
-        if other._Tem_av_ref != self._Tem_av_ref:
-            diff_list.append(name + ".Tem_av_ref")
-        if other._Id_ref != self._Id_ref:
-            diff_list.append(name + ".Id_ref")
-        if other._Iq_ref != self._Iq_ref:
-            diff_list.append(name + ".Iq_ref")
-        if other._felec != self._felec:
-            diff_list.append(name + ".felec")
-        if other._Ud_ref != self._Ud_ref:
-            diff_list.append(name + ".Ud_ref")
-        if other._Uq_ref != self._Uq_ref:
-            diff_list.append(name + ".Uq_ref")
         if other._Pj_losses != self._Pj_losses:
             diff_list.append(name + ".Pj_losses")
-        if other._Pem_av_ref != self._Pem_av_ref:
-            diff_list.append(name + ".Pem_av_ref")
         if (other.Us is None and self.Us is not None) or (
             other.Us is not None and self.Us is None
         ):
@@ -342,6 +335,34 @@ class OutElec(FrozenClass):
             diff_list.extend(
                 self.internal.compare(other.internal, name=name + ".internal")
             )
+        if (other.Us_PWM is None and self.Us_PWM is not None) or (
+            other.Us_PWM is not None and self.Us_PWM is None
+        ):
+            diff_list.append(name + ".Us_PWM None mismatch")
+        elif self.Us_PWM is not None:
+            diff_list.extend(self.Us_PWM.compare(other.Us_PWM, name=name + ".Us_PWM"))
+        if (other.OP is None and self.OP is not None) or (
+            other.OP is not None and self.OP is None
+        ):
+            diff_list.append(name + ".OP None mismatch")
+        elif self.OP is not None:
+            diff_list.extend(self.OP.compare(other.OP, name=name + ".OP"))
+        if other._Pem_av_ref != self._Pem_av_ref:
+            diff_list.append(name + ".Pem_av_ref")
+        if other._Tem_av_ref != self._Tem_av_ref:
+            diff_list.append(name + ".Tem_av_ref")
+        if (other.Is_harm is None and self.Is_harm is not None) or (
+            other.Is_harm is not None and self.Is_harm is None
+        ):
+            diff_list.append(name + ".Is_harm None mismatch")
+        elif self.Is_harm is not None:
+            diff_list.extend(
+                self.Is_harm.compare(other.Is_harm, name=name + ".Is_harm")
+            )
+        if other._phase_dir != self._phase_dir:
+            diff_list.append(name + ".phase_dir")
+        if other._current_dir != self._current_dir:
+            diff_list.append(name + ".current_dir")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -350,24 +371,22 @@ class OutElec(FrozenClass):
         """Return the size in memory of the object (including all subobject)"""
 
         S = 0  # Full size of the object
-        S += getsizeof(self.Time)
-        S += getsizeof(self.Angle)
+        if self.axes_dict is not None:
+            for key, value in self.axes_dict.items():
+                S += getsizeof(value) + getsizeof(key)
         S += getsizeof(self.Is)
         S += getsizeof(self.Ir)
-        S += getsizeof(self.angle_rotor)
-        S += getsizeof(self.N0)
-        S += getsizeof(self.angle_rotor_initial)
         S += getsizeof(self.logger_name)
-        S += getsizeof(self.Tem_av_ref)
-        S += getsizeof(self.Id_ref)
-        S += getsizeof(self.Iq_ref)
-        S += getsizeof(self.felec)
-        S += getsizeof(self.Ud_ref)
-        S += getsizeof(self.Uq_ref)
         S += getsizeof(self.Pj_losses)
-        S += getsizeof(self.Pem_av_ref)
         S += getsizeof(self.Us)
         S += getsizeof(self.internal)
+        S += getsizeof(self.Us_PWM)
+        S += getsizeof(self.OP)
+        S += getsizeof(self.Pem_av_ref)
+        S += getsizeof(self.Tem_av_ref)
+        S += getsizeof(self.Is_harm)
+        S += getsizeof(self.phase_dir)
+        S += getsizeof(self.current_dir)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -382,22 +401,19 @@ class OutElec(FrozenClass):
         """
 
         OutElec_dict = dict()
-        if self.Time is None:
-            OutElec_dict["Time"] = None
+        if self.axes_dict is None:
+            OutElec_dict["axes_dict"] = None
         else:
-            OutElec_dict["Time"] = self.Time.as_dict(
-                type_handle_ndarray=type_handle_ndarray,
-                keep_function=keep_function,
-                **kwargs
-            )
-        if self.Angle is None:
-            OutElec_dict["Angle"] = None
-        else:
-            OutElec_dict["Angle"] = self.Angle.as_dict(
-                type_handle_ndarray=type_handle_ndarray,
-                keep_function=keep_function,
-                **kwargs
-            )
+            OutElec_dict["axes_dict"] = dict()
+            for key, obj in self.axes_dict.items():
+                if obj is not None:
+                    OutElec_dict["axes_dict"][key] = obj.as_dict(
+                        type_handle_ndarray=type_handle_ndarray,
+                        keep_function=keep_function,
+                        **kwargs
+                    )
+                else:
+                    OutElec_dict["axes_dict"][key] = None
         if self.Is is None:
             OutElec_dict["Is"] = None
         else:
@@ -414,30 +430,8 @@ class OutElec(FrozenClass):
                 keep_function=keep_function,
                 **kwargs
             )
-        if self.angle_rotor is None:
-            OutElec_dict["angle_rotor"] = None
-        else:
-            if type_handle_ndarray == 0:
-                OutElec_dict["angle_rotor"] = self.angle_rotor.tolist()
-            elif type_handle_ndarray == 1:
-                OutElec_dict["angle_rotor"] = self.angle_rotor.copy()
-            elif type_handle_ndarray == 2:
-                OutElec_dict["angle_rotor"] = self.angle_rotor
-            else:
-                raise Exception(
-                    "Unknown type_handle_ndarray: " + str(type_handle_ndarray)
-                )
-        OutElec_dict["N0"] = self.N0
-        OutElec_dict["angle_rotor_initial"] = self.angle_rotor_initial
         OutElec_dict["logger_name"] = self.logger_name
-        OutElec_dict["Tem_av_ref"] = self.Tem_av_ref
-        OutElec_dict["Id_ref"] = self.Id_ref
-        OutElec_dict["Iq_ref"] = self.Iq_ref
-        OutElec_dict["felec"] = self.felec
-        OutElec_dict["Ud_ref"] = self.Ud_ref
-        OutElec_dict["Uq_ref"] = self.Uq_ref
         OutElec_dict["Pj_losses"] = self.Pj_losses
-        OutElec_dict["Pem_av_ref"] = self.Pem_av_ref
         if self.Us is None:
             OutElec_dict["Us"] = None
         else:
@@ -454,6 +448,34 @@ class OutElec(FrozenClass):
                 keep_function=keep_function,
                 **kwargs
             )
+        if self.Us_PWM is None:
+            OutElec_dict["Us_PWM"] = None
+        else:
+            OutElec_dict["Us_PWM"] = self.Us_PWM.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
+        if self.OP is None:
+            OutElec_dict["OP"] = None
+        else:
+            OutElec_dict["OP"] = self.OP.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
+        OutElec_dict["Pem_av_ref"] = self.Pem_av_ref
+        OutElec_dict["Tem_av_ref"] = self.Tem_av_ref
+        if self.Is_harm is None:
+            OutElec_dict["Is_harm"] = None
+        else:
+            OutElec_dict["Is_harm"] = self.Is_harm.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
+        OutElec_dict["phase_dir"] = self.phase_dir
+        OutElec_dict["current_dir"] = self.current_dir
         # The class name is added to the dict for deserialisation purpose
         OutElec_dict["__class__"] = "OutElec"
         return OutElec_dict
@@ -461,77 +483,51 @@ class OutElec(FrozenClass):
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
-        self.Time = None
-        self.Angle = None
+        self.axes_dict = None
         self.Is = None
         self.Ir = None
-        self.angle_rotor = None
-        self.N0 = None
-        self.angle_rotor_initial = None
         self.logger_name = None
-        self.Tem_av_ref = None
-        self.Id_ref = None
-        self.Iq_ref = None
-        self.felec = None
-        self.Ud_ref = None
-        self.Uq_ref = None
         self.Pj_losses = None
-        self.Pem_av_ref = None
         self.Us = None
         if self.internal is not None:
             self.internal._set_None()
+        self.Us_PWM = None
+        if self.OP is not None:
+            self.OP._set_None()
+        self.Pem_av_ref = None
+        self.Tem_av_ref = None
+        self.Is_harm = None
+        self.phase_dir = None
+        self.current_dir = None
 
-    def _get_Time(self):
-        """getter of Time"""
-        return self._Time
+    def _get_axes_dict(self):
+        """getter of axes_dict"""
+        if self._axes_dict is not None:
+            for key, obj in self._axes_dict.items():
+                if obj is not None:
+                    obj.parent = self
+        return self._axes_dict
 
-    def _set_Time(self, value):
-        """setter of Time"""
-        if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
-        if isinstance(value, dict) and "__class__" in value:
-            class_obj = import_class(
-                "SciDataTool.Classes", value.get("__class__"), "Time"
-            )
-            value = class_obj(init_dict=value)
-        elif type(value) is int and value == -1:  # Default constructor
-            value = Data()
-        check_var("Time", value, "Data")
-        self._Time = value
+    def _set_axes_dict(self, value):
+        """setter of axes_dict"""
+        if type(value) is dict:
+            for key, obj in value.items():
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "SciDataTool.Classes", obj.get("__class__"), "axes_dict"
+                    )
+                    value[key] = class_obj(init_dict=obj)
+        if type(value) is int and value == -1:
+            value = dict()
+        check_var("axes_dict", value, "{Data}")
+        self._axes_dict = value
 
-    Time = property(
-        fget=_get_Time,
-        fset=_set_Time,
-        doc=u"""Electrical time Data object
+    axes_dict = property(
+        fget=_get_axes_dict,
+        fset=_set_axes_dict,
+        doc=u"""Dict containing axes data used for Electrical
 
-        :Type: SciDataTool.Classes.DataND.Data
-        """,
-    )
-
-    def _get_Angle(self):
-        """getter of Angle"""
-        return self._Angle
-
-    def _set_Angle(self, value):
-        """setter of Angle"""
-        if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
-        if isinstance(value, dict) and "__class__" in value:
-            class_obj = import_class(
-                "SciDataTool.Classes", value.get("__class__"), "Angle"
-            )
-            value = class_obj(init_dict=value)
-        elif type(value) is int and value == -1:  # Default constructor
-            value = Data()
-        check_var("Angle", value, "Data")
-        self._Angle = value
-
-    Angle = property(
-        fget=_get_Angle,
-        fset=_set_Angle,
-        doc=u"""Electrical position Data object
-
-        :Type: SciDataTool.Classes.DataND.Data
+        :Type: {SciDataTool.Classes.DataND.Data}
         """,
     )
 
@@ -589,67 +585,6 @@ class OutElec(FrozenClass):
         """,
     )
 
-    def _get_angle_rotor(self):
-        """getter of angle_rotor"""
-        return self._angle_rotor
-
-    def _set_angle_rotor(self, value):
-        """setter of angle_rotor"""
-        if type(value) is int and value == -1:
-            value = array([])
-        elif type(value) is list:
-            try:
-                value = array(value)
-            except:
-                pass
-        check_var("angle_rotor", value, "ndarray")
-        self._angle_rotor = value
-
-    angle_rotor = property(
-        fget=_get_angle_rotor,
-        fset=_set_angle_rotor,
-        doc=u"""Rotor angular position as a function of time (if None computed according to Nr)
-
-        :Type: ndarray
-        """,
-    )
-
-    def _get_N0(self):
-        """getter of N0"""
-        return self._N0
-
-    def _set_N0(self, value):
-        """setter of N0"""
-        check_var("N0", value, "float")
-        self._N0 = value
-
-    N0 = property(
-        fget=_get_N0,
-        fset=_set_N0,
-        doc=u"""Rotor speed
-
-        :Type: float
-        """,
-    )
-
-    def _get_angle_rotor_initial(self):
-        """getter of angle_rotor_initial"""
-        return self._angle_rotor_initial
-
-    def _set_angle_rotor_initial(self, value):
-        """setter of angle_rotor_initial"""
-        check_var("angle_rotor_initial", value, "float")
-        self._angle_rotor_initial = value
-
-    angle_rotor_initial = property(
-        fget=_get_angle_rotor_initial,
-        fset=_set_angle_rotor_initial,
-        doc=u"""Initial angular position of the rotor at t=0
-
-        :Type: float
-        """,
-    )
-
     def _get_logger_name(self):
         """getter of logger_name"""
         return self._logger_name
@@ -668,114 +603,6 @@ class OutElec(FrozenClass):
         """,
     )
 
-    def _get_Tem_av_ref(self):
-        """getter of Tem_av_ref"""
-        return self._Tem_av_ref
-
-    def _set_Tem_av_ref(self, value):
-        """setter of Tem_av_ref"""
-        check_var("Tem_av_ref", value, "float")
-        self._Tem_av_ref = value
-
-    Tem_av_ref = property(
-        fget=_get_Tem_av_ref,
-        fset=_set_Tem_av_ref,
-        doc=u"""Theorical Average Electromagnetic torque
-
-        :Type: float
-        """,
-    )
-
-    def _get_Id_ref(self):
-        """getter of Id_ref"""
-        return self._Id_ref
-
-    def _set_Id_ref(self, value):
-        """setter of Id_ref"""
-        check_var("Id_ref", value, "float")
-        self._Id_ref = value
-
-    Id_ref = property(
-        fget=_get_Id_ref,
-        fset=_set_Id_ref,
-        doc=u"""Electrical time vector (no symmetry)
-
-        :Type: float
-        """,
-    )
-
-    def _get_Iq_ref(self):
-        """getter of Iq_ref"""
-        return self._Iq_ref
-
-    def _set_Iq_ref(self, value):
-        """setter of Iq_ref"""
-        check_var("Iq_ref", value, "float")
-        self._Iq_ref = value
-
-    Iq_ref = property(
-        fget=_get_Iq_ref,
-        fset=_set_Iq_ref,
-        doc=u"""q-axis current magnitude
-
-        :Type: float
-        """,
-    )
-
-    def _get_felec(self):
-        """getter of felec"""
-        return self._felec
-
-    def _set_felec(self, value):
-        """setter of felec"""
-        check_var("felec", value, "float")
-        self._felec = value
-
-    felec = property(
-        fget=_get_felec,
-        fset=_set_felec,
-        doc=u"""Electrical Frequency
-
-        :Type: float
-        """,
-    )
-
-    def _get_Ud_ref(self):
-        """getter of Ud_ref"""
-        return self._Ud_ref
-
-    def _set_Ud_ref(self, value):
-        """setter of Ud_ref"""
-        check_var("Ud_ref", value, "float")
-        self._Ud_ref = value
-
-    Ud_ref = property(
-        fget=_get_Ud_ref,
-        fset=_set_Ud_ref,
-        doc=u"""d-axis voltage magnitude
-
-        :Type: float
-        """,
-    )
-
-    def _get_Uq_ref(self):
-        """getter of Uq_ref"""
-        return self._Uq_ref
-
-    def _set_Uq_ref(self, value):
-        """setter of Uq_ref"""
-        check_var("Uq_ref", value, "float")
-        self._Uq_ref = value
-
-    Uq_ref = property(
-        fget=_get_Uq_ref,
-        fset=_set_Uq_ref,
-        doc=u"""q-axis voltage magnitude
-
-        :Type: float
-        """,
-    )
-
     def _get_Pj_losses(self):
         """getter of Pj_losses"""
         return self._Pj_losses
@@ -794,24 +621,6 @@ class OutElec(FrozenClass):
         """,
     )
 
-    def _get_Pem_av_ref(self):
-        """getter of Pem_av_ref"""
-        return self._Pem_av_ref
-
-    def _set_Pem_av_ref(self, value):
-        """setter of Pem_av_ref"""
-        check_var("Pem_av_ref", value, "float")
-        self._Pem_av_ref = value
-
-    Pem_av_ref = property(
-        fget=_get_Pem_av_ref,
-        fset=_set_Pem_av_ref,
-        doc=u"""Theorical Average Electromagnetic Power
-
-        :Type: float
-        """,
-    )
-
     def _get_Us(self):
         """getter of Us"""
         return self._Us
@@ -868,3 +677,161 @@ class OutElec(FrozenClass):
         :Type: OutInternal
         """,
     )
+
+    def _get_Us_PWM(self):
+        """getter of Us_PWM"""
+        return self._Us_PWM
+
+    def _set_Us_PWM(self, value):
+        """setter of Us_PWM"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "Us_PWM"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = DataND()
+        check_var("Us_PWM", value, "DataND")
+        self._Us_PWM = value
+
+    Us_PWM = property(
+        fget=_get_Us_PWM,
+        fset=_set_Us_PWM,
+        doc=u"""PWM stator voltage as a function of time (each column correspond to one phase)
+
+        :Type: SciDataTool.Classes.DataND.DataND
+        """,
+    )
+
+    def _get_OP(self):
+        """getter of OP"""
+        return self._OP
+
+    def _set_OP(self, value):
+        """setter of OP"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class("pyleecan.Classes", value.get("__class__"), "OP")
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = OP()
+        check_var("OP", value, "OP")
+        self._OP = value
+
+        if self._OP is not None:
+            self._OP.parent = self
+
+    OP = property(
+        fget=_get_OP,
+        fset=_set_OP,
+        doc=u"""Operating Point
+
+        :Type: OP
+        """,
+    )
+
+    def _get_Pem_av_ref(self):
+        """getter of Pem_av_ref"""
+        return self._Pem_av_ref
+
+    def _set_Pem_av_ref(self, value):
+        """setter of Pem_av_ref"""
+        check_var("Pem_av_ref", value, "float")
+        self._Pem_av_ref = value
+
+    Pem_av_ref = property(
+        fget=_get_Pem_av_ref,
+        fset=_set_Pem_av_ref,
+        doc=u"""Theorical Average Electromagnetic Power
+
+        :Type: float
+        """,
+    )
+
+    def _get_Tem_av_ref(self):
+        """getter of Tem_av_ref"""
+        return self._Tem_av_ref
+
+    def _set_Tem_av_ref(self, value):
+        """setter of Tem_av_ref"""
+        check_var("Tem_av_ref", value, "float")
+        self._Tem_av_ref = value
+
+    Tem_av_ref = property(
+        fget=_get_Tem_av_ref,
+        fset=_set_Tem_av_ref,
+        doc=u"""Theorical Average Electromagnetic torque
+
+        :Type: float
+        """,
+    )
+
+    def _get_Is_harm(self):
+        """getter of Is_harm"""
+        return self._Is_harm
+
+    def _set_Is_harm(self, value):
+        """setter of Is_harm"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "Is_harm"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = DataND()
+        check_var("Is_harm", value, "DataND")
+        self._Is_harm = value
+
+    Is_harm = property(
+        fget=_get_Is_harm,
+        fset=_set_Is_harm,
+        doc=u"""Harmonic stator current 
+
+        :Type: SciDataTool.Classes.DataND.DataND
+        """,
+    )
+
+    def _get_phase_dir(self):
+        """getter of phase_dir"""
+        return self._phase_dir
+
+    def _set_phase_dir(self, value):
+        """setter of phase_dir"""
+        check_var("phase_dir", value, "int", Vmin=-1, Vmax=1)
+        self._phase_dir = value
+
+    phase_dir = property(
+        fget=_get_phase_dir,
+        fset=_set_phase_dir,
+        doc=u"""Rotation direction of the stator phases (phase_dir*(n-1)*pi/qs, default value given by PHASE_DIR_REF)
+
+        :Type: int
+        :min: -1
+        :max: 1
+        """,
+    )
+
+    def _get_current_dir(self):
+        """getter of current_dir"""
+        return self._current_dir
+
+    def _set_current_dir(self, value):
+        """setter of current_dir"""
+        check_var("current_dir", value, "int", Vmin=-1, Vmax=1)
+        self._current_dir = value
+
+    current_dir = property(
+        fget=_get_current_dir,
+        fset=_set_current_dir,
+        doc=u"""Rotation direction of the stator currents (current_dir*2*pi*felec*time, default value given by CURRENT_DIR_REF)
+
+        :Type: int
+        :min: -1
+        :max: 1
+        """,
+    )
