@@ -39,12 +39,15 @@ class OutGeo(FrozenClass):
         Rgap_mec=None,
         Lgap=None,
         logger_name="Pyleecan.OutGeo",
-        angle_offset_initial=None,
+        angle_rotor_initial=None,
         rot_dir=None,
         per_a=None,
         is_antiper_a=None,
-        per_t=None,
-        is_antiper_t=None,
+        per_t_S=None,
+        is_antiper_t_S=None,
+        axes_dict=None,
+        per_t_R=None,
+        is_antiper_t_R=None,
         init_dict=None,
         init_str=None,
     ):
@@ -77,18 +80,24 @@ class OutGeo(FrozenClass):
                 Lgap = init_dict["Lgap"]
             if "logger_name" in list(init_dict.keys()):
                 logger_name = init_dict["logger_name"]
-            if "angle_offset_initial" in list(init_dict.keys()):
-                angle_offset_initial = init_dict["angle_offset_initial"]
+            if "angle_rotor_initial" in list(init_dict.keys()):
+                angle_rotor_initial = init_dict["angle_rotor_initial"]
             if "rot_dir" in list(init_dict.keys()):
                 rot_dir = init_dict["rot_dir"]
             if "per_a" in list(init_dict.keys()):
                 per_a = init_dict["per_a"]
             if "is_antiper_a" in list(init_dict.keys()):
                 is_antiper_a = init_dict["is_antiper_a"]
-            if "per_t" in list(init_dict.keys()):
-                per_t = init_dict["per_t"]
-            if "is_antiper_t" in list(init_dict.keys()):
-                is_antiper_t = init_dict["is_antiper_t"]
+            if "per_t_S" in list(init_dict.keys()):
+                per_t_S = init_dict["per_t_S"]
+            if "is_antiper_t_S" in list(init_dict.keys()):
+                is_antiper_t_S = init_dict["is_antiper_t_S"]
+            if "axes_dict" in list(init_dict.keys()):
+                axes_dict = init_dict["axes_dict"]
+            if "per_t_R" in list(init_dict.keys()):
+                per_t_R = init_dict["per_t_R"]
+            if "is_antiper_t_R" in list(init_dict.keys()):
+                is_antiper_t_R = init_dict["is_antiper_t_R"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.stator = stator
@@ -98,12 +107,15 @@ class OutGeo(FrozenClass):
         self.Rgap_mec = Rgap_mec
         self.Lgap = Lgap
         self.logger_name = logger_name
-        self.angle_offset_initial = angle_offset_initial
+        self.angle_rotor_initial = angle_rotor_initial
         self.rot_dir = rot_dir
         self.per_a = per_a
         self.is_antiper_a = is_antiper_a
-        self.per_t = per_t
-        self.is_antiper_t = is_antiper_t
+        self.per_t_S = per_t_S
+        self.is_antiper_t_S = is_antiper_t_S
+        self.axes_dict = axes_dict
+        self.per_t_R = per_t_R
+        self.is_antiper_t_R = is_antiper_t_R
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -131,14 +143,15 @@ class OutGeo(FrozenClass):
         OutGeo_str += "Rgap_mec = " + str(self.Rgap_mec) + linesep
         OutGeo_str += "Lgap = " + str(self.Lgap) + linesep
         OutGeo_str += 'logger_name = "' + str(self.logger_name) + '"' + linesep
-        OutGeo_str += (
-            "angle_offset_initial = " + str(self.angle_offset_initial) + linesep
-        )
+        OutGeo_str += "angle_rotor_initial = " + str(self.angle_rotor_initial) + linesep
         OutGeo_str += "rot_dir = " + str(self.rot_dir) + linesep
         OutGeo_str += "per_a = " + str(self.per_a) + linesep
         OutGeo_str += "is_antiper_a = " + str(self.is_antiper_a) + linesep
-        OutGeo_str += "per_t = " + str(self.per_t) + linesep
-        OutGeo_str += "is_antiper_t = " + str(self.is_antiper_t) + linesep
+        OutGeo_str += "per_t_S = " + str(self.per_t_S) + linesep
+        OutGeo_str += "is_antiper_t_S = " + str(self.is_antiper_t_S) + linesep
+        OutGeo_str += "axes_dict = " + str(self.axes_dict) + linesep + linesep
+        OutGeo_str += "per_t_R = " + str(self.per_t_R) + linesep
+        OutGeo_str += "is_antiper_t_R = " + str(self.is_antiper_t_R) + linesep
         return OutGeo_str
 
     def __eq__(self, other):
@@ -160,7 +173,7 @@ class OutGeo(FrozenClass):
             return False
         if other.logger_name != self.logger_name:
             return False
-        if other.angle_offset_initial != self.angle_offset_initial:
+        if other.angle_rotor_initial != self.angle_rotor_initial:
             return False
         if other.rot_dir != self.rot_dir:
             return False
@@ -168,9 +181,15 @@ class OutGeo(FrozenClass):
             return False
         if other.is_antiper_a != self.is_antiper_a:
             return False
-        if other.per_t != self.per_t:
+        if other.per_t_S != self.per_t_S:
             return False
-        if other.is_antiper_t != self.is_antiper_t:
+        if other.is_antiper_t_S != self.is_antiper_t_S:
+            return False
+        if other.axes_dict != self.axes_dict:
+            return False
+        if other.per_t_R != self.per_t_R:
+            return False
+        if other.is_antiper_t_R != self.is_antiper_t_R:
             return False
         return True
 
@@ -204,18 +223,37 @@ class OutGeo(FrozenClass):
             diff_list.append(name + ".Lgap")
         if other._logger_name != self._logger_name:
             diff_list.append(name + ".logger_name")
-        if other._angle_offset_initial != self._angle_offset_initial:
-            diff_list.append(name + ".angle_offset_initial")
+        if other._angle_rotor_initial != self._angle_rotor_initial:
+            diff_list.append(name + ".angle_rotor_initial")
         if other._rot_dir != self._rot_dir:
             diff_list.append(name + ".rot_dir")
         if other._per_a != self._per_a:
             diff_list.append(name + ".per_a")
         if other._is_antiper_a != self._is_antiper_a:
             diff_list.append(name + ".is_antiper_a")
-        if other._per_t != self._per_t:
-            diff_list.append(name + ".per_t")
-        if other._is_antiper_t != self._is_antiper_t:
-            diff_list.append(name + ".is_antiper_t")
+        if other._per_t_S != self._per_t_S:
+            diff_list.append(name + ".per_t_S")
+        if other._is_antiper_t_S != self._is_antiper_t_S:
+            diff_list.append(name + ".is_antiper_t_S")
+        if (other.axes_dict is None and self.axes_dict is not None) or (
+            other.axes_dict is not None and self.axes_dict is None
+        ):
+            diff_list.append(name + ".axes_dict None mismatch")
+        elif self.axes_dict is None:
+            pass
+        elif len(other.axes_dict) != len(self.axes_dict):
+            diff_list.append("len(" + name + "axes_dict)")
+        else:
+            for key in self.axes_dict:
+                diff_list.extend(
+                    self.axes_dict[key].compare(
+                        other.axes_dict[key], name=name + ".axes_dict"
+                    )
+                )
+        if other._per_t_R != self._per_t_R:
+            diff_list.append(name + ".per_t_R")
+        if other._is_antiper_t_R != self._is_antiper_t_R:
+            diff_list.append(name + ".is_antiper_t_R")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -231,12 +269,17 @@ class OutGeo(FrozenClass):
         S += getsizeof(self.Rgap_mec)
         S += getsizeof(self.Lgap)
         S += getsizeof(self.logger_name)
-        S += getsizeof(self.angle_offset_initial)
+        S += getsizeof(self.angle_rotor_initial)
         S += getsizeof(self.rot_dir)
         S += getsizeof(self.per_a)
         S += getsizeof(self.is_antiper_a)
-        S += getsizeof(self.per_t)
-        S += getsizeof(self.is_antiper_t)
+        S += getsizeof(self.per_t_S)
+        S += getsizeof(self.is_antiper_t_S)
+        if self.axes_dict is not None:
+            for key, value in self.axes_dict.items():
+                S += getsizeof(value) + getsizeof(key)
+        S += getsizeof(self.per_t_R)
+        S += getsizeof(self.is_antiper_t_R)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -272,12 +315,27 @@ class OutGeo(FrozenClass):
         OutGeo_dict["Rgap_mec"] = self.Rgap_mec
         OutGeo_dict["Lgap"] = self.Lgap
         OutGeo_dict["logger_name"] = self.logger_name
-        OutGeo_dict["angle_offset_initial"] = self.angle_offset_initial
+        OutGeo_dict["angle_rotor_initial"] = self.angle_rotor_initial
         OutGeo_dict["rot_dir"] = self.rot_dir
         OutGeo_dict["per_a"] = self.per_a
         OutGeo_dict["is_antiper_a"] = self.is_antiper_a
-        OutGeo_dict["per_t"] = self.per_t
-        OutGeo_dict["is_antiper_t"] = self.is_antiper_t
+        OutGeo_dict["per_t_S"] = self.per_t_S
+        OutGeo_dict["is_antiper_t_S"] = self.is_antiper_t_S
+        if self.axes_dict is None:
+            OutGeo_dict["axes_dict"] = None
+        else:
+            OutGeo_dict["axes_dict"] = dict()
+            for key, obj in self.axes_dict.items():
+                if obj is not None:
+                    OutGeo_dict["axes_dict"][key] = obj.as_dict(
+                        type_handle_ndarray=type_handle_ndarray,
+                        keep_function=keep_function,
+                        **kwargs
+                    )
+                else:
+                    OutGeo_dict["axes_dict"][key] = None
+        OutGeo_dict["per_t_R"] = self.per_t_R
+        OutGeo_dict["is_antiper_t_R"] = self.is_antiper_t_R
         # The class name is added to the dict for deserialisation purpose
         OutGeo_dict["__class__"] = "OutGeo"
         return OutGeo_dict
@@ -294,12 +352,15 @@ class OutGeo(FrozenClass):
         self.Rgap_mec = None
         self.Lgap = None
         self.logger_name = None
-        self.angle_offset_initial = None
+        self.angle_rotor_initial = None
         self.rot_dir = None
         self.per_a = None
         self.is_antiper_a = None
-        self.per_t = None
-        self.is_antiper_t = None
+        self.per_t_S = None
+        self.is_antiper_t_S = None
+        self.axes_dict = None
+        self.per_t_R = None
+        self.is_antiper_t_R = None
 
     def _get_stator(self):
         """getter of stator"""
@@ -451,18 +512,18 @@ class OutGeo(FrozenClass):
         """,
     )
 
-    def _get_angle_offset_initial(self):
-        """getter of angle_offset_initial"""
-        return self._angle_offset_initial
+    def _get_angle_rotor_initial(self):
+        """getter of angle_rotor_initial"""
+        return self._angle_rotor_initial
 
-    def _set_angle_offset_initial(self, value):
-        """setter of angle_offset_initial"""
-        check_var("angle_offset_initial", value, "float")
-        self._angle_offset_initial = value
+    def _set_angle_rotor_initial(self, value):
+        """setter of angle_rotor_initial"""
+        check_var("angle_rotor_initial", value, "float")
+        self._angle_rotor_initial = value
 
-    angle_offset_initial = property(
-        fget=_get_angle_offset_initial,
-        fset=_set_angle_offset_initial,
+    angle_rotor_initial = property(
+        fget=_get_angle_rotor_initial,
+        fset=_set_angle_rotor_initial,
         doc=u"""Difference between the d axis angle of the stator and the rotor
 
         :Type: float
@@ -481,7 +542,7 @@ class OutGeo(FrozenClass):
     rot_dir = property(
         fget=_get_rot_dir,
         fset=_set_rot_dir,
-        doc=u"""rotation direction of the magnetic field fundamental !! WARNING: rot_dir = -1 to have positive rotor rotating direction, i.e. rotor position moves towards positive angle
+        doc=u"""Rotation direction of the rotor (rot_dir*N0, default value given by ROT_DIR_REF)
 
         :Type: int
         :min: -1
@@ -525,37 +586,104 @@ class OutGeo(FrozenClass):
         """,
     )
 
-    def _get_per_t(self):
-        """getter of per_t"""
-        return self._per_t
+    def _get_per_t_S(self):
+        """getter of per_t_S"""
+        return self._per_t_S
 
-    def _set_per_t(self, value):
-        """setter of per_t"""
-        check_var("per_t", value, "int")
-        self._per_t = value
+    def _set_per_t_S(self, value):
+        """setter of per_t_S"""
+        check_var("per_t_S", value, "int")
+        self._per_t_S = value
 
-    per_t = property(
-        fget=_get_per_t,
-        fset=_set_per_t,
-        doc=u"""Number of time periodicities of the machine
+    per_t_S = property(
+        fget=_get_per_t_S,
+        fset=_set_per_t_S,
+        doc=u"""Number of time periodicities of the machine in static referential
 
         :Type: int
         """,
     )
 
-    def _get_is_antiper_t(self):
-        """getter of is_antiper_t"""
-        return self._is_antiper_t
+    def _get_is_antiper_t_S(self):
+        """getter of is_antiper_t_S"""
+        return self._is_antiper_t_S
 
-    def _set_is_antiper_t(self, value):
-        """setter of is_antiper_t"""
-        check_var("is_antiper_t", value, "bool")
-        self._is_antiper_t = value
+    def _set_is_antiper_t_S(self, value):
+        """setter of is_antiper_t_S"""
+        check_var("is_antiper_t_S", value, "bool")
+        self._is_antiper_t_S = value
 
-    is_antiper_t = property(
-        fget=_get_is_antiper_t,
-        fset=_set_is_antiper_t,
-        doc=u"""True if an time anti-periodicity is possible after the periodicities
+    is_antiper_t_S = property(
+        fget=_get_is_antiper_t_S,
+        fset=_set_is_antiper_t_S,
+        doc=u"""True if an time anti-periodicity is possible after the periodicities in static referential
+
+        :Type: bool
+        """,
+    )
+
+    def _get_axes_dict(self):
+        """getter of axes_dict"""
+        if self._axes_dict is not None:
+            for key, obj in self._axes_dict.items():
+                if obj is not None:
+                    obj.parent = self
+        return self._axes_dict
+
+    def _set_axes_dict(self, value):
+        """setter of axes_dict"""
+        if type(value) is dict:
+            for key, obj in value.items():
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "SciDataTool.Classes", obj.get("__class__"), "axes_dict"
+                    )
+                    value[key] = class_obj(init_dict=obj)
+        if type(value) is int and value == -1:
+            value = dict()
+        check_var("axes_dict", value, "{Data}")
+        self._axes_dict = value
+
+    axes_dict = property(
+        fget=_get_axes_dict,
+        fset=_set_axes_dict,
+        doc=u"""Dict containing axes data without periodicities used for plots and to have simulation full time/angle vectors
+
+        :Type: {SciDataTool.Classes.DataND.Data}
+        """,
+    )
+
+    def _get_per_t_R(self):
+        """getter of per_t_R"""
+        return self._per_t_R
+
+    def _set_per_t_R(self, value):
+        """setter of per_t_R"""
+        check_var("per_t_R", value, "int")
+        self._per_t_R = value
+
+    per_t_R = property(
+        fget=_get_per_t_R,
+        fset=_set_per_t_R,
+        doc=u"""Number of time periodicities of the machine in rotating referential
+
+        :Type: int
+        """,
+    )
+
+    def _get_is_antiper_t_R(self):
+        """getter of is_antiper_t_R"""
+        return self._is_antiper_t_R
+
+    def _set_is_antiper_t_R(self, value):
+        """setter of is_antiper_t_R"""
+        check_var("is_antiper_t_R", value, "bool")
+        self._is_antiper_t_R = value
+
+    is_antiper_t_R = property(
+        fget=_get_is_antiper_t_R,
+        fset=_set_is_antiper_t_R,
+        doc=u"""True if an time anti-periodicity is possible after the periodicities in rotating referential
 
         :Type: bool
         """,
