@@ -17,11 +17,6 @@ from ._frozen import FrozenClass
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
-try:
-    from ..Methods.Output.OutMag.store import store
-except ImportError as error:
-    store = error
-
 try:
     from ..Methods.Output.OutMag.clean import clean
 except ImportError as error:
@@ -32,20 +27,26 @@ try:
 except ImportError as error:
     comp_emf = error
 
+try:
+    from ..Methods.Output.OutMag.comp_power import comp_power
+except ImportError as error:
+    comp_power = error
+
 try:
     from ..Methods.Output.OutMag.get_demag import get_demag
 except ImportError as error:
     get_demag = error
 
 try:
-    from ..Methods.Output.OutMag.comp_power import comp_power
+    from ..Methods.Output.OutMag.store import store
 except ImportError as error:
-    comp_power = error
+    store = error
 
 
 from ._check import InitUnKnowClassError
 from .MeshSolution import MeshSolution
 from .OutInternal import OutInternal
+from .SliceModel import SliceModel
 
 
 class OutMag(FrozenClass):
@@ -54,15 +55,6 @@ class OutMag(FrozenClass):
     VERSION = 1
 
     # Check ImportError to remove unnecessary dependencies in unused method
-    # cf Methods.Output.OutMag.store
-    if isinstance(store, ImportError):
-        store = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use OutMag method store: " + str(store))
-            )
-        )
-    else:
-        store = store
     # cf Methods.Output.OutMag.clean
     if isinstance(clean, ImportError):
         clean = property(
@@ -81,15 +73,6 @@ class OutMag(FrozenClass):
         )
     else:
         comp_emf = comp_emf
-    # cf Methods.Output.OutMag.get_demag
-    if isinstance(get_demag, ImportError):
-        get_demag = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use OutMag method get_demag: " + str(get_demag))
-            )
-        )
-    else:
-        get_demag = get_demag
     # cf Methods.Output.OutMag.comp_power
     if isinstance(comp_power, ImportError):
         comp_power = property(
@@ -99,6 +82,24 @@ class OutMag(FrozenClass):
         )
     else:
         comp_power = comp_power
+    # cf Methods.Output.OutMag.get_demag
+    if isinstance(get_demag, ImportError):
+        get_demag = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use OutMag method get_demag: " + str(get_demag))
+            )
+        )
+    else:
+        get_demag = get_demag
+    # cf Methods.Output.OutMag.store
+    if isinstance(store, ImportError):
+        store = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use OutMag method store: " + str(store))
+            )
+        )
+    else:
+        store = store
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -107,8 +108,7 @@ class OutMag(FrozenClass):
 
     def __init__(
         self,
-        Time=None,
-        Angle=None,
+        axes_dict=None,
         B=None,
         Tem=None,
         Tem_av=None,
@@ -122,6 +122,9 @@ class OutMag(FrozenClass):
         internal=None,
         Rag=None,
         Pem_av=None,
+        Slice=None,
+        Tem_slice=None,
+        Phi_wind_slice=None,
         init_dict=None,
         init_str=None,
     ):
@@ -140,10 +143,8 @@ class OutMag(FrozenClass):
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
-            if "Time" in list(init_dict.keys()):
-                Time = init_dict["Time"]
-            if "Angle" in list(init_dict.keys()):
-                Angle = init_dict["Angle"]
+            if "axes_dict" in list(init_dict.keys()):
+                axes_dict = init_dict["axes_dict"]
             if "B" in list(init_dict.keys()):
                 B = init_dict["B"]
             if "Tem" in list(init_dict.keys()):
@@ -170,10 +171,15 @@ class OutMag(FrozenClass):
                 Rag = init_dict["Rag"]
             if "Pem_av" in list(init_dict.keys()):
                 Pem_av = init_dict["Pem_av"]
+            if "Slice" in list(init_dict.keys()):
+                Slice = init_dict["Slice"]
+            if "Tem_slice" in list(init_dict.keys()):
+                Tem_slice = init_dict["Tem_slice"]
+            if "Phi_wind_slice" in list(init_dict.keys()):
+                Phi_wind_slice = init_dict["Phi_wind_slice"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
-        self.Time = Time
-        self.Angle = Angle
+        self.axes_dict = axes_dict
         self.B = B
         self.Tem = Tem
         self.Tem_av = Tem_av
@@ -187,6 +193,9 @@ class OutMag(FrozenClass):
         self.internal = internal
         self.Rag = Rag
         self.Pem_av = Pem_av
+        self.Slice = Slice
+        self.Tem_slice = Tem_slice
+        self.Phi_wind_slice = Phi_wind_slice
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -199,8 +208,7 @@ class OutMag(FrozenClass):
             OutMag_str += "parent = None " + linesep
         else:
             OutMag_str += "parent = " + str(type(self.parent)) + " object" + linesep
-        OutMag_str += "Time = " + str(self.Time) + linesep + linesep
-        OutMag_str += "Angle = " + str(self.Angle) + linesep + linesep
+        OutMag_str += "axes_dict = " + str(self.axes_dict) + linesep + linesep
         OutMag_str += "B = " + str(self.B) + linesep + linesep
         OutMag_str += "Tem = " + str(self.Tem) + linesep + linesep
         OutMag_str += "Tem_av = " + str(self.Tem_av) + linesep
@@ -228,6 +236,13 @@ class OutMag(FrozenClass):
             OutMag_str += "internal = None" + linesep + linesep
         OutMag_str += "Rag = " + str(self.Rag) + linesep
         OutMag_str += "Pem_av = " + str(self.Pem_av) + linesep
+        if self.Slice is not None:
+            tmp = self.Slice.__str__().replace(linesep, linesep + "\t").rstrip("\t")
+            OutMag_str += "Slice = " + tmp
+        else:
+            OutMag_str += "Slice = None" + linesep + linesep
+        OutMag_str += "Tem_slice = " + str(self.Tem_slice) + linesep + linesep
+        OutMag_str += "Phi_wind_slice = " + str(self.Phi_wind_slice) + linesep + linesep
         return OutMag_str
 
     def __eq__(self, other):
@@ -235,9 +250,7 @@ class OutMag(FrozenClass):
 
         if type(other) != type(self):
             return False
-        if other.Time != self.Time:
-            return False
-        if other.Angle != self.Angle:
+        if other.axes_dict != self.axes_dict:
             return False
         if other.B != self.B:
             return False
@@ -265,6 +278,12 @@ class OutMag(FrozenClass):
             return False
         if other.Pem_av != self.Pem_av:
             return False
+        if other.Slice != self.Slice:
+            return False
+        if other.Tem_slice != self.Tem_slice:
+            return False
+        if other.Phi_wind_slice != self.Phi_wind_slice:
+            return False
         return True
 
     def compare(self, other, name="self", ignore_list=None):
@@ -275,18 +294,21 @@ class OutMag(FrozenClass):
         if type(other) != type(self):
             return ["type(" + name + ")"]
         diff_list = list()
-        if (other.Time is None and self.Time is not None) or (
-            other.Time is not None and self.Time is None
+        if (other.axes_dict is None and self.axes_dict is not None) or (
+            other.axes_dict is not None and self.axes_dict is None
         ):
-            diff_list.append(name + ".Time None mismatch")
-        elif self.Time is not None:
-            diff_list.extend(self.Time.compare(other.Time, name=name + ".Time"))
-        if (other.Angle is None and self.Angle is not None) or (
-            other.Angle is not None and self.Angle is None
-        ):
-            diff_list.append(name + ".Angle None mismatch")
-        elif self.Angle is not None:
-            diff_list.extend(self.Angle.compare(other.Angle, name=name + ".Angle"))
+            diff_list.append(name + ".axes_dict None mismatch")
+        elif self.axes_dict is None:
+            pass
+        elif len(other.axes_dict) != len(self.axes_dict):
+            diff_list.append("len(" + name + "axes_dict)")
+        else:
+            for key in self.axes_dict:
+                diff_list.extend(
+                    self.axes_dict[key].compare(
+                        other.axes_dict[key], name=name + ".axes_dict"
+                    )
+                )
         if (other.B is None and self.B is not None) or (
             other.B is not None and self.B is None
         ):
@@ -360,6 +382,35 @@ class OutMag(FrozenClass):
             diff_list.append(name + ".Rag")
         if other._Pem_av != self._Pem_av:
             diff_list.append(name + ".Pem_av")
+        if (other.Slice is None and self.Slice is not None) or (
+            other.Slice is not None and self.Slice is None
+        ):
+            diff_list.append(name + ".Slice None mismatch")
+        elif self.Slice is not None:
+            diff_list.extend(self.Slice.compare(other.Slice, name=name + ".Slice"))
+        if (other.Tem_slice is None and self.Tem_slice is not None) or (
+            other.Tem_slice is not None and self.Tem_slice is None
+        ):
+            diff_list.append(name + ".Tem_slice None mismatch")
+        elif self.Tem_slice is not None:
+            diff_list.extend(
+                self.Tem_slice.compare(other.Tem_slice, name=name + ".Tem_slice")
+            )
+        if (other.Phi_wind_slice is None and self.Phi_wind_slice is not None) or (
+            other.Phi_wind_slice is not None and self.Phi_wind_slice is None
+        ):
+            diff_list.append(name + ".Phi_wind_slice None mismatch")
+        elif self.Phi_wind_slice is None:
+            pass
+        elif len(other.Phi_wind_slice) != len(self.Phi_wind_slice):
+            diff_list.append("len(" + name + "Phi_wind_slice)")
+        else:
+            for key in self.Phi_wind_slice:
+                diff_list.extend(
+                    self.Phi_wind_slice[key].compare(
+                        other.Phi_wind_slice[key], name=name + ".Phi_wind_slice"
+                    )
+                )
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -368,8 +419,9 @@ class OutMag(FrozenClass):
         """Return the size in memory of the object (including all subobject)"""
 
         S = 0  # Full size of the object
-        S += getsizeof(self.Time)
-        S += getsizeof(self.Angle)
+        if self.axes_dict is not None:
+            for key, value in self.axes_dict.items():
+                S += getsizeof(value) + getsizeof(key)
         S += getsizeof(self.B)
         S += getsizeof(self.Tem)
         S += getsizeof(self.Tem_av)
@@ -385,6 +437,11 @@ class OutMag(FrozenClass):
         S += getsizeof(self.internal)
         S += getsizeof(self.Rag)
         S += getsizeof(self.Pem_av)
+        S += getsizeof(self.Slice)
+        S += getsizeof(self.Tem_slice)
+        if self.Phi_wind_slice is not None:
+            for key, value in self.Phi_wind_slice.items():
+                S += getsizeof(value) + getsizeof(key)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -399,22 +456,19 @@ class OutMag(FrozenClass):
         """
 
         OutMag_dict = dict()
-        if self.Time is None:
-            OutMag_dict["Time"] = None
+        if self.axes_dict is None:
+            OutMag_dict["axes_dict"] = None
         else:
-            OutMag_dict["Time"] = self.Time.as_dict(
-                type_handle_ndarray=type_handle_ndarray,
-                keep_function=keep_function,
-                **kwargs
-            )
-        if self.Angle is None:
-            OutMag_dict["Angle"] = None
-        else:
-            OutMag_dict["Angle"] = self.Angle.as_dict(
-                type_handle_ndarray=type_handle_ndarray,
-                keep_function=keep_function,
-                **kwargs
-            )
+            OutMag_dict["axes_dict"] = dict()
+            for key, obj in self.axes_dict.items():
+                if obj is not None:
+                    OutMag_dict["axes_dict"][key] = obj.as_dict(
+                        type_handle_ndarray=type_handle_ndarray,
+                        keep_function=keep_function,
+                        **kwargs
+                    )
+                else:
+                    OutMag_dict["axes_dict"][key] = None
         if self.B is None:
             OutMag_dict["B"] = None
         else:
@@ -482,6 +536,35 @@ class OutMag(FrozenClass):
             )
         OutMag_dict["Rag"] = self.Rag
         OutMag_dict["Pem_av"] = self.Pem_av
+        if self.Slice is None:
+            OutMag_dict["Slice"] = None
+        else:
+            OutMag_dict["Slice"] = self.Slice.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
+        if self.Tem_slice is None:
+            OutMag_dict["Tem_slice"] = None
+        else:
+            OutMag_dict["Tem_slice"] = self.Tem_slice.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
+        if self.Phi_wind_slice is None:
+            OutMag_dict["Phi_wind_slice"] = None
+        else:
+            OutMag_dict["Phi_wind_slice"] = dict()
+            for key, obj in self.Phi_wind_slice.items():
+                if obj is not None:
+                    OutMag_dict["Phi_wind_slice"][key] = obj.as_dict(
+                        type_handle_ndarray=type_handle_ndarray,
+                        keep_function=keep_function,
+                        **kwargs
+                    )
+                else:
+                    OutMag_dict["Phi_wind_slice"][key] = None
         # The class name is added to the dict for deserialisation purpose
         OutMag_dict["__class__"] = "OutMag"
         return OutMag_dict
@@ -489,8 +572,7 @@ class OutMag(FrozenClass):
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
-        self.Time = None
-        self.Angle = None
+        self.axes_dict = None
         self.B = None
         self.Tem = None
         self.Tem_av = None
@@ -506,58 +588,39 @@ class OutMag(FrozenClass):
             self.internal._set_None()
         self.Rag = None
         self.Pem_av = None
+        if self.Slice is not None:
+            self.Slice._set_None()
+        self.Tem_slice = None
+        self.Phi_wind_slice = None
 
-    def _get_Time(self):
-        """getter of Time"""
-        return self._Time
+    def _get_axes_dict(self):
+        """getter of axes_dict"""
+        if self._axes_dict is not None:
+            for key, obj in self._axes_dict.items():
+                if obj is not None:
+                    obj.parent = self
+        return self._axes_dict
 
-    def _set_Time(self, value):
-        """setter of Time"""
-        if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
-        if isinstance(value, dict) and "__class__" in value:
-            class_obj = import_class(
-                "SciDataTool.Classes", value.get("__class__"), "Time"
-            )
-            value = class_obj(init_dict=value)
-        elif type(value) is int and value == -1:  # Default constructor
-            value = Data()
-        check_var("Time", value, "Data")
-        self._Time = value
+    def _set_axes_dict(self, value):
+        """setter of axes_dict"""
+        if type(value) is dict:
+            for key, obj in value.items():
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "SciDataTool.Classes", obj.get("__class__"), "axes_dict"
+                    )
+                    value[key] = class_obj(init_dict=obj)
+        if type(value) is int and value == -1:
+            value = dict()
+        check_var("axes_dict", value, "{Data}")
+        self._axes_dict = value
 
-    Time = property(
-        fget=_get_Time,
-        fset=_set_Time,
-        doc=u"""Magnetic time Data object
+    axes_dict = property(
+        fget=_get_axes_dict,
+        fset=_set_axes_dict,
+        doc=u"""Dict containing axes data used for Magnetics
 
-        :Type: SciDataTool.Classes.DataND.Data
-        """,
-    )
-
-    def _get_Angle(self):
-        """getter of Angle"""
-        return self._Angle
-
-    def _set_Angle(self, value):
-        """setter of Angle"""
-        if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
-        if isinstance(value, dict) and "__class__" in value:
-            class_obj = import_class(
-                "SciDataTool.Classes", value.get("__class__"), "Angle"
-            )
-            value = class_obj(init_dict=value)
-        elif type(value) is int and value == -1:  # Default constructor
-            value = Data()
-        check_var("Angle", value, "Data")
-        self._Angle = value
-
-    Angle = property(
-        fget=_get_Angle,
-        fset=_set_Angle,
-        doc=u"""Magnetic position Data object
-
-        :Type: SciDataTool.Classes.DataND.Data
+        :Type: {SciDataTool.Classes.DataND.Data}
         """,
     )
 
@@ -681,8 +744,8 @@ class OutMag(FrozenClass):
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
-            value = DataTime()
-        check_var("Phi_wind_stator", value, "DataTime")
+            value = DataND()
+        check_var("Phi_wind_stator", value, "DataND")
         self._Phi_wind_stator = value
 
     Phi_wind_stator = property(
@@ -690,7 +753,7 @@ class OutMag(FrozenClass):
         fset=_set_Phi_wind_stator,
         doc=u"""Stator winding flux DataTime object
 
-        :Type: SciDataTool.Classes.DataTime.DataTime
+        :Type: SciDataTool.Classes.DataND.DataND
         """,
     )
 
@@ -713,7 +776,7 @@ class OutMag(FrozenClass):
                     value[key] = class_obj(init_dict=obj)
         if type(value) is int and value == -1:
             value = dict()
-        check_var("Phi_wind", value, "{DataTime}")
+        check_var("Phi_wind", value, "{DataND}")
         self._Phi_wind = value
 
     Phi_wind = property(
@@ -721,7 +784,7 @@ class OutMag(FrozenClass):
         fset=_set_Phi_wind,
         doc=u"""Dict of lamination winding fluxlinkage DataTime objects
 
-        :Type: {SciDataTool.Classes.DataTime.DataTime}
+        :Type: {SciDataTool.Classes.DataND.DataND}
         """,
     )
 
@@ -739,8 +802,8 @@ class OutMag(FrozenClass):
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
-            value = DataTime()
-        check_var("emf", value, "DataTime")
+            value = DataND()
+        check_var("emf", value, "DataND")
         self._emf = value
 
     emf = property(
@@ -748,7 +811,7 @@ class OutMag(FrozenClass):
         fset=_set_emf,
         doc=u"""Electromotive force DataTime object
 
-        :Type: SciDataTool.Classes.DataTime.DataTime
+        :Type: SciDataTool.Classes.DataND.DataND
         """,
     )
 
@@ -865,3 +928,91 @@ class OutMag(FrozenClass):
         :Type: float
         """,
     )
+
+    def _get_Slice(self):
+        """getter of Slice"""
+        return self._Slice
+
+    def _set_Slice(self, value):
+        """setter of Slice"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "pyleecan.Classes", value.get("__class__"), "Slice"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = SliceModel()
+        check_var("Slice", value, "SliceModel")
+        self._Slice = value
+
+        if self._Slice is not None:
+            self._Slice.parent = self
+
+    Slice = property(
+        fget=_get_Slice,
+        fset=_set_Slice,
+        doc=u"""Slice model to account for skew
+
+        :Type: SliceModel
+        """,
+    )
+
+    def _get_Tem_slice(self):
+        """getter of Tem_slice"""
+        return self._Tem_slice
+
+    def _set_Tem_slice(self, value):
+        """setter of Tem_slice"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "SciDataTool.Classes", value.get("__class__"), "Tem_slice"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = DataND()
+        check_var("Tem_slice", value, "DataND")
+        self._Tem_slice = value
+
+    Tem_slice = property(
+        fget=_get_Tem_slice,
+        fset=_set_Tem_slice,
+        doc=u"""Electromagnetic torque DataTime object including torque per slice
+
+        :Type: SciDataTool.Classes.DataND.DataND
+        """,
+    )
+
+    def _get_Phi_wind_slice(self):
+        """getter of Phi_wind_slice"""
+        if self._Phi_wind_slice is not None:
+            for key, obj in self._Phi_wind_slice.items():
+                if obj is not None:
+                    obj.parent = self
+        return self._Phi_wind_slice
+
+    def _set_Phi_wind_slice(self, value):
+        """setter of Phi_wind_slice"""
+        if type(value) is dict:
+            for key, obj in value.items():
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "SciDataTool.Classes", obj.get("__class__"), "Phi_wind_slice"
+                    )
+                    value[key] = class_obj(init_dict=obj)
+        if type(value) is int and value == -1:
+            value = dict()
+        check_var("Phi_wind_slice", value, "{DataND}")
+        self._Phi_wind_slice = value
+
+    Phi_wind_slice = property(
+        fget=_get_Phi_wind_slice,
+        fset=_set_Phi_wind_slice,
+        doc=u"""Dict of lamination winding fluxlinkage DataTime objects per slice
+
+        :Type: {SciDataTool.Classes.DataND.DataND}
+        """,
+    )
