@@ -476,9 +476,13 @@ class VarSimu(FrozenClass):
                 S += getsizeof(value)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
@@ -492,7 +496,13 @@ class VarSimu(FrozenClass):
             VarSimu_dict["datakeeper_list"] = list()
             for obj in self.datakeeper_list:
                 if obj is not None:
-                    VarSimu_dict["datakeeper_list"].append(obj.as_dict(**kwargs))
+                    VarSimu_dict["datakeeper_list"].append(
+                        obj.as_dict(
+                            type_handle_ndarray=type_handle_ndarray,
+                            keep_function=keep_function,
+                            **kwargs
+                        )
+                    )
                 else:
                     VarSimu_dict["datakeeper_list"].append(None)
         VarSimu_dict["is_keep_all_output"] = self.is_keep_all_output
@@ -500,7 +510,11 @@ class VarSimu(FrozenClass):
         if self.var_simu is None:
             VarSimu_dict["var_simu"] = None
         else:
-            VarSimu_dict["var_simu"] = self.var_simu.as_dict(**kwargs)
+            VarSimu_dict["var_simu"] = self.var_simu.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         VarSimu_dict["nb_simu"] = self.nb_simu
         VarSimu_dict["is_reuse_femm_file"] = self.is_reuse_femm_file
         if self.postproc_list is None:
@@ -509,7 +523,13 @@ class VarSimu(FrozenClass):
             VarSimu_dict["postproc_list"] = list()
             for obj in self.postproc_list:
                 if obj is not None:
-                    VarSimu_dict["postproc_list"].append(obj.as_dict(**kwargs))
+                    VarSimu_dict["postproc_list"].append(
+                        obj.as_dict(
+                            type_handle_ndarray=type_handle_ndarray,
+                            keep_function=keep_function,
+                            **kwargs
+                        )
+                    )
                 else:
                     VarSimu_dict["postproc_list"].append(None)
         if self.pre_keeper_postproc_list is None:
@@ -519,7 +539,11 @@ class VarSimu(FrozenClass):
             for obj in self.pre_keeper_postproc_list:
                 if obj is not None:
                     VarSimu_dict["pre_keeper_postproc_list"].append(
-                        obj.as_dict(**kwargs)
+                        obj.as_dict(
+                            type_handle_ndarray=type_handle_ndarray,
+                            keep_function=keep_function,
+                            **kwargs
+                        )
                     )
                 else:
                     VarSimu_dict["pre_keeper_postproc_list"].append(None)
@@ -530,7 +554,11 @@ class VarSimu(FrozenClass):
             for obj in self.post_keeper_postproc_list:
                 if obj is not None:
                     VarSimu_dict["post_keeper_postproc_list"].append(
-                        obj.as_dict(**kwargs)
+                        obj.as_dict(
+                            type_handle_ndarray=type_handle_ndarray,
+                            keep_function=keep_function,
+                            **kwargs
+                        )
                     )
                 else:
                     VarSimu_dict["post_keeper_postproc_list"].append(None)
