@@ -42,6 +42,18 @@ try:
 except ImportError as error:
     get_center = error
 
+try:
+    from ..Methods.Slot.VentilationCirc._comp_point_coordinate import (
+        _comp_point_coordinate,
+    )
+except ImportError as error:
+    _comp_point_coordinate = error
+
+try:
+    from ..Methods.Slot.VentilationCirc.plot_schematics import plot_schematics
+except ImportError as error:
+    plot_schematics = error
+
 
 from ._check import InitUnKnowClassError
 from .Material import Material
@@ -108,6 +120,30 @@ class VentilationCirc(Hole):
         )
     else:
         get_center = get_center
+    # cf Methods.Slot.VentilationCirc._comp_point_coordinate
+    if isinstance(_comp_point_coordinate, ImportError):
+        _comp_point_coordinate = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use VentilationCirc method _comp_point_coordinate: "
+                    + str(_comp_point_coordinate)
+                )
+            )
+        )
+    else:
+        _comp_point_coordinate = _comp_point_coordinate
+    # cf Methods.Slot.VentilationCirc.plot_schematics
+    if isinstance(plot_schematics, ImportError):
+        plot_schematics = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use VentilationCirc method plot_schematics: "
+                    + str(plot_schematics)
+                )
+            )
+        )
+    else:
+        plot_schematics = plot_schematics
     # save and copy methods are available in all object
     save = save
     copy = copy
