@@ -27,6 +27,11 @@ try:
 except ImportError as error:
     get_dim_wind = error
 
+try:
+    from ..Methods.Machine.WindingSC.comp_periodicity import comp_periodicity
+except ImportError as error:
+    comp_periodicity = error
+
 
 from numpy import array, array_equal
 from ._check import InitUnKnowClassError
@@ -64,6 +69,18 @@ class WindingSC(Winding):
         )
     else:
         get_dim_wind = get_dim_wind
+    # cf Methods.Machine.WindingSC.comp_periodicity
+    if isinstance(comp_periodicity, ImportError):
+        comp_periodicity = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use WindingSC method comp_periodicity: "
+                    + str(comp_periodicity)
+                )
+            )
+        )
+    else:
+        comp_periodicity = comp_periodicity
     # save and copy methods are available in all object
     save = save
     copy = copy
