@@ -10,9 +10,8 @@ def comp_FEMM_torque(femm, FEMM_dict, sym=1):
 
     # Select rotor groups
     femm.mo_seteditmode("area")
-    femm.mo_groupselectblock(FEMM_dict["groups"]["GROUP_RC"])
-    femm.mo_groupselectblock(FEMM_dict["groups"]["GROUP_RH"])
-    femm.mo_groupselectblock(FEMM_dict["groups"]["GROUP_RW"])
-    femm.mo_groupselectblock(FEMM_dict["groups"]["GROUP_RM"])
+    femm.mo_groupselectblock(FEMM_dict["groups"]["GROUP_RC"])  # rotor core
+    femm.mo_groupselectblock(FEMM_dict["groups"]["GROUP_RW"])  # rotor winding
+    femm.mo_groupselectblock(FEMM_dict["groups"]["GROUP_RM"])  # rotor magnet
     # sym = 2 => Only half the machine
     return sym * femm.mo_blockintegral(22)
