@@ -19,13 +19,11 @@ class Ui_PVentTrap(object):
     def setupUi(self, PVentTrap):
         if not PVentTrap.objectName():
             PVentTrap.setObjectName(u"PVentTrap")
-        PVentTrap.resize(630, 470)
-        PVentTrap.setMinimumSize(QSize(630, 470))
+        PVentTrap.resize(700, 470)
+        PVentTrap.setMinimumSize(QSize(700, 470))
         PVentTrap.setMaximumSize(QSize(16777215, 16777215))
         self.horizontalLayout = QHBoxLayout(PVentTrap)
         self.horizontalLayout.setObjectName(u"horizontalLayout")
-        self.verticalLayout_2 = QVBoxLayout()
-        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
         self.img_vent = QLabel(PVentTrap)
         self.img_vent.setObjectName(u"img_vent")
         sizePolicy = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
@@ -33,113 +31,129 @@ class Ui_PVentTrap(object):
         sizePolicy.setVerticalStretch(0)
         sizePolicy.setHeightForWidth(self.img_vent.sizePolicy().hasHeightForWidth())
         self.img_vent.setSizePolicy(sizePolicy)
+        self.img_vent.setMinimumSize(QSize(410, 300))
         self.img_vent.setMaximumSize(QSize(16777215, 16777215))
         self.img_vent.setPixmap(
-            QPixmap(u":/images/images/MachineSetup/LamParam/TrapVentDuct.png")
+            QPixmap(u":/images/images/MachineSetup/LamParam/VentilationTrap.png")
         )
-        self.img_vent.setScaledContents(True)
+        self.img_vent.setScaledContents(False)
+        self.img_vent.setAlignment(Qt.AlignCenter)
 
-        self.verticalLayout_2.addWidget(self.img_vent)
+        self.horizontalLayout.addWidget(self.img_vent)
 
-        self.horizontalLayout.addLayout(self.verticalLayout_2)
-
-        self.verticalLayout = QVBoxLayout()
+        self.scrollArea = QScrollArea(PVentTrap)
+        self.scrollArea.setObjectName(u"scrollArea")
+        self.scrollArea.setMinimumSize(QSize(300, 0))
+        self.scrollArea.setMaximumSize(QSize(300, 16777215))
+        self.scrollArea.setWidgetResizable(True)
+        self.scrollAreaWidgetContents = QWidget()
+        self.scrollAreaWidgetContents.setObjectName(u"scrollAreaWidgetContents")
+        self.scrollAreaWidgetContents.setGeometry(QRect(0, 0, 298, 446))
+        self.verticalLayout = QVBoxLayout(self.scrollAreaWidgetContents)
         self.verticalLayout.setObjectName(u"verticalLayout")
         self.gridLayout = QGridLayout()
         self.gridLayout.setObjectName(u"gridLayout")
-        self.in_Zh = QLabel(PVentTrap)
+        self.in_Zh = QLabel(self.scrollAreaWidgetContents)
         self.in_Zh.setObjectName(u"in_Zh")
 
         self.gridLayout.addWidget(self.in_Zh, 0, 0, 1, 1)
 
-        self.in_H0 = QLabel(PVentTrap)
-        self.in_H0.setObjectName(u"in_H0")
-
-        self.gridLayout.addWidget(self.in_H0, 1, 0, 1, 1)
-
-        self.lf_H0 = FloatEdit(PVentTrap)
-        self.lf_H0.setObjectName(u"lf_H0")
-
-        self.gridLayout.addWidget(self.lf_H0, 1, 1, 1, 1)
-
-        self.unit_H0 = QLabel(PVentTrap)
-        self.unit_H0.setObjectName(u"unit_H0")
-
-        self.gridLayout.addWidget(self.unit_H0, 1, 2, 1, 1)
-
-        self.in_D0 = QLabel(PVentTrap)
-        self.in_D0.setObjectName(u"in_D0")
-
-        self.gridLayout.addWidget(self.in_D0, 2, 0, 1, 1)
-
-        self.lf_D0 = FloatEdit(PVentTrap)
-        self.lf_D0.setObjectName(u"lf_D0")
-
-        self.gridLayout.addWidget(self.lf_D0, 2, 1, 1, 1)
-
-        self.unit_D0 = QLabel(PVentTrap)
-        self.unit_D0.setObjectName(u"unit_D0")
-
-        self.gridLayout.addWidget(self.unit_D0, 2, 2, 1, 1)
-
-        self.in_W1 = QLabel(PVentTrap)
-        self.in_W1.setObjectName(u"in_W1")
-
-        self.gridLayout.addWidget(self.in_W1, 3, 0, 1, 1)
-
-        self.lf_W1 = FloatEdit(PVentTrap)
-        self.lf_W1.setObjectName(u"lf_W1")
-
-        self.gridLayout.addWidget(self.lf_W1, 3, 1, 1, 1)
-
-        self.unit_W1 = QLabel(PVentTrap)
-        self.unit_W1.setObjectName(u"unit_W1")
-
-        self.gridLayout.addWidget(self.unit_W1, 3, 2, 1, 1)
-
-        self.in_W2 = QLabel(PVentTrap)
-        self.in_W2.setObjectName(u"in_W2")
-
-        self.gridLayout.addWidget(self.in_W2, 4, 0, 1, 1)
-
-        self.lf_W2 = FloatEdit(PVentTrap)
-        self.lf_W2.setObjectName(u"lf_W2")
-
-        self.gridLayout.addWidget(self.lf_W2, 4, 1, 1, 1)
-
-        self.unit_W2 = QLabel(PVentTrap)
-        self.unit_W2.setObjectName(u"unit_W2")
-
-        self.gridLayout.addWidget(self.unit_W2, 4, 2, 1, 1)
-
-        self.in_Alpha0 = QLabel(PVentTrap)
-        self.in_Alpha0.setObjectName(u"in_Alpha0")
-
-        self.gridLayout.addWidget(self.in_Alpha0, 5, 0, 1, 1)
-
-        self.lf_Alpha0 = FloatEdit(PVentTrap)
-        self.lf_Alpha0.setObjectName(u"lf_Alpha0")
-
-        self.gridLayout.addWidget(self.lf_Alpha0, 5, 1, 1, 1)
-
-        self.unit_Alpha0 = QLabel(PVentTrap)
-        self.unit_Alpha0.setObjectName(u"unit_Alpha0")
-
-        self.gridLayout.addWidget(self.unit_Alpha0, 5, 2, 1, 1)
-
-        self.si_Zh = QSpinBox(PVentTrap)
+        self.si_Zh = QSpinBox(self.scrollAreaWidgetContents)
         self.si_Zh.setObjectName(u"si_Zh")
 
         self.gridLayout.addWidget(self.si_Zh, 0, 1, 1, 1)
 
+        self.in_H0 = QLabel(self.scrollAreaWidgetContents)
+        self.in_H0.setObjectName(u"in_H0")
+
+        self.gridLayout.addWidget(self.in_H0, 1, 0, 1, 1)
+
+        self.lf_H0 = FloatEdit(self.scrollAreaWidgetContents)
+        self.lf_H0.setObjectName(u"lf_H0")
+
+        self.gridLayout.addWidget(self.lf_H0, 1, 1, 1, 1)
+
+        self.unit_H0 = QLabel(self.scrollAreaWidgetContents)
+        self.unit_H0.setObjectName(u"unit_H0")
+
+        self.gridLayout.addWidget(self.unit_H0, 1, 2, 1, 1)
+
+        self.in_D0 = QLabel(self.scrollAreaWidgetContents)
+        self.in_D0.setObjectName(u"in_D0")
+
+        self.gridLayout.addWidget(self.in_D0, 2, 0, 1, 1)
+
+        self.lf_D0 = FloatEdit(self.scrollAreaWidgetContents)
+        self.lf_D0.setObjectName(u"lf_D0")
+
+        self.gridLayout.addWidget(self.lf_D0, 2, 1, 1, 1)
+
+        self.unit_D0 = QLabel(self.scrollAreaWidgetContents)
+        self.unit_D0.setObjectName(u"unit_D0")
+
+        self.gridLayout.addWidget(self.unit_D0, 2, 2, 1, 1)
+
+        self.in_W1 = QLabel(self.scrollAreaWidgetContents)
+        self.in_W1.setObjectName(u"in_W1")
+
+        self.gridLayout.addWidget(self.in_W1, 3, 0, 1, 1)
+
+        self.lf_W1 = FloatEdit(self.scrollAreaWidgetContents)
+        self.lf_W1.setObjectName(u"lf_W1")
+
+        self.gridLayout.addWidget(self.lf_W1, 3, 1, 1, 1)
+
+        self.unit_W1 = QLabel(self.scrollAreaWidgetContents)
+        self.unit_W1.setObjectName(u"unit_W1")
+
+        self.gridLayout.addWidget(self.unit_W1, 3, 2, 1, 1)
+
+        self.in_W2 = QLabel(self.scrollAreaWidgetContents)
+        self.in_W2.setObjectName(u"in_W2")
+
+        self.gridLayout.addWidget(self.in_W2, 4, 0, 1, 1)
+
+        self.lf_W2 = FloatEdit(self.scrollAreaWidgetContents)
+        self.lf_W2.setObjectName(u"lf_W2")
+
+        self.gridLayout.addWidget(self.lf_W2, 4, 1, 1, 1)
+
+        self.unit_W2 = QLabel(self.scrollAreaWidgetContents)
+        self.unit_W2.setObjectName(u"unit_W2")
+
+        self.gridLayout.addWidget(self.unit_W2, 4, 2, 1, 1)
+
+        self.in_Alpha0 = QLabel(self.scrollAreaWidgetContents)
+        self.in_Alpha0.setObjectName(u"in_Alpha0")
+
+        self.gridLayout.addWidget(self.in_Alpha0, 5, 0, 1, 1)
+
+        self.lf_Alpha0 = FloatEdit(self.scrollAreaWidgetContents)
+        self.lf_Alpha0.setObjectName(u"lf_Alpha0")
+
+        self.gridLayout.addWidget(self.lf_Alpha0, 5, 1, 1, 1)
+
+        self.unit_Alpha0 = QLabel(self.scrollAreaWidgetContents)
+        self.unit_Alpha0.setObjectName(u"unit_Alpha0")
+
+        self.gridLayout.addWidget(self.unit_Alpha0, 5, 2, 1, 1)
+
         self.verticalLayout.addLayout(self.gridLayout)
 
-        self.w_out = WVentOut(PVentTrap)
+        self.verticalSpacer = QSpacerItem(
+            20, 228, QSizePolicy.Minimum, QSizePolicy.Expanding
+        )
+
+        self.verticalLayout.addItem(self.verticalSpacer)
+
+        self.w_out = WVentOut(self.scrollAreaWidgetContents)
         self.w_out.setObjectName(u"w_out")
 
         self.verticalLayout.addWidget(self.w_out)
 
-        self.horizontalLayout.addLayout(self.verticalLayout)
+        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
+
+        self.horizontalLayout.addWidget(self.scrollArea)
 
         QWidget.setTabOrder(self.lf_H0, self.lf_D0)
         QWidget.setTabOrder(self.lf_D0, self.lf_Alpha0)
@@ -165,6 +179,8 @@ class Ui_PVentTrap(object):
         self.in_Alpha0.setText(
             QCoreApplication.translate("PVentTrap", u"Alpha0 :", None)
         )
-        self.unit_Alpha0.setText(QCoreApplication.translate("PVentTrap", u"rad", None))
+        self.unit_Alpha0.setText(
+            QCoreApplication.translate("PVentTrap", u"[rad]", None)
+        )
 
     # retranslateUi
