@@ -16,7 +16,7 @@ class WVentOut(QGroupBox):
         # Init the main widget
         self.u = gui_option.unit
         self.setTitle(self.tr("Output"))
-        self.setMinimumSize(QSize(300, 0))
+        self.setMinimumSize(QSize(200, 0))
         self.setObjectName("g_output")
         self.layout = QVBoxLayout(self)
         self.layout.setObjectName("layout")
@@ -42,6 +42,9 @@ class WVentOut(QGroupBox):
         self.out_vent_surf.setObjectName("out_vent_surf")
         self.layout.addWidget(self.out_vent_surf)
 
+        self.out_sp = QLabel(self)
+        self.out_sp.setObjectName("out_sp")
+        self.layout.addWidget(self.out_sp)
         # self.layout.addWidget(self)
 
     def comp_output(self):
@@ -53,45 +56,49 @@ class WVentOut(QGroupBox):
             A WVentOut object
         """
 
-        lam = self.parent().lam
+        if hasattr(self.parent(), "lam"):
+            lam = self.parent().lam
+            vent = self.parent().vent
+        else:  # For VentUD
+            lam = self.parent().parent().parent().parent().lam
+            vent = self.parent().parent().parent().parent().vent
 
         # Lamination output
-        Rint = format(self.u.get_m(lam.Rint), ".4g")
-        self.out_Rint.setText(
-            self.tr("Lam. internal radius: ") + Rint + " " + self.u.get_m_name()
-        )
+        # Rint = format(self.u.get_m(lam.Rint), ".4g")
+        # self.out_Rint.setText(lam_name + ".Rint: " + Rint + " " + self.u.get_m_name())
+        self.out_Rint.hide()
 
-        Rext = format(self.u.get_m(lam.Rext), ".4g")
-        self.out_Rext.setText(
-            self.tr("Lam. external radius: ") + Rext + " " + self.u.get_m_name()
-        )
-        Slam = format(self.u.get_m2(pi * (lam.Rext ** 2 - lam.Rint ** 2)), ".4g")
+        # Rext = format(self.u.get_m(lam.Rext), ".4g")
+        # self.out_Rext.setText(lam_name + ".Rext: " + Rext + " " + self.u.get_m_name())
+        self.out_Rext.hide()
+
+        if vent.Zh not in [None, 0]:
+            sp_txt = format(pi / vent.Zh, ".4g") + " [rad]"
+        else:
+            sp_txt = "?"
+        self.out_sp.setText("pi / Zh : " + sp_txt)
+
+        Slam = pi * (lam.Rext ** 2 - lam.Rint ** 2)
+        Slam_txt = format(self.u.get_m2(Slam), ".4g")
         self.out_lam_surface.setText(
-            self.tr("Lam. surface (no slot, no vent): ")
-            + Slam
-            + " "
-            + self.u.get_m2_name()
+            "Active surface: " + Slam_txt + " [" + self.u.get_m2_name() + "]"
         )
+        self.out_lam_vent_surface.hide()
+
         # Ventilation output
         try:
-            lam = Lamination(Rext=lam.Rext, Rint=lam.Rint)
-
-            lam.axial_vent = self.parent().lam.axial_vent
-            Svent = format(self.u.get_m2(lam.comp_surface_axial_vent()), ".4g")
+            Svent = lam.comp_surface_axial_vent()
         except Exception:
             Svent = 0
-            self.out_lam_vent_surface.setText(
-                self.tr("Lam. surface (no slot, with vent): ?")
-            )
-            self.out_vent_surf.setText(self.tr("Vent surface: ?"))
+
         if Svent != 0:
-            Slv = format(float(Slam) - float(Svent), ".4g")
-            self.out_lam_vent_surface.setText(
-                self.tr("Lam. surface (no slot, with vent): ")
-                + Slv
-                + " "
-                + self.u.get_m2_name()
+            Slv = format(self.u.get_m2(float(Slam) - float(Svent)), ".4g")
+            Svent = format(self.u.get_m2(float(Svent)), ".4g")
+            self.out_lam_surface.setText(
+                self.tr("Active surface: ") + Slv + " [" + self.u.get_m2_name() + "]"
             )
             self.out_vent_surf.setText(
-                self.tr("Vent surface: ") + Svent + " " + self.u.get_m2_name()
+                self.tr("Cooling surface: ") + Svent + " [" + self.u.get_m2_name() + "]"
             )
+        else:
+            self.out_vent_surf.setText(self.tr("Cooling surface: ?"))
