@@ -38,7 +38,8 @@ class Ui_PHoleM52(object):
         self.img_slot.setPixmap(
             QPixmap(u":/images/images/MachineSetup/SMHoleMag/HoleM52.png")
         )
-        self.img_slot.setScaledContents(True)
+        self.img_slot.setScaledContents(False)
+        self.img_slot.setAlignment(Qt.AlignCenter)
 
         self.verticalLayout_3.addWidget(self.img_slot)
 
