@@ -19,7 +19,7 @@ class Ui_PMSlot11(object):
     def setupUi(self, PMSlot11):
         if not PMSlot11.objectName():
             PMSlot11.setObjectName(u"PMSlot11")
-        PMSlot11.resize(877, 470)
+        PMSlot11.resize(866, 555)
         PMSlot11.setMinimumSize(QSize(630, 470))
         PMSlot11.setMaximumSize(QSize(16777215, 16777215))
         self.horizontalLayout = QHBoxLayout(PMSlot11)
@@ -37,20 +37,19 @@ class Ui_PMSlot11(object):
         self.img_slot.setPixmap(
             QPixmap(u":/images/images/MachineSetup/WMSlot/SlotM11.png")
         )
-        self.img_slot.setScaledContents(True)
+        self.img_slot.setScaledContents(False)
+        self.img_slot.setAlignment(Qt.AlignCenter)
 
         self.verticalLayout_2.addWidget(self.img_slot)
 
         self.txt_constraint = QTextEdit(PMSlot11)
         self.txt_constraint.setObjectName(u"txt_constraint")
-        sizePolicy1 = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
-        sizePolicy1.setHorizontalStretch(0)
-        sizePolicy1.setVerticalStretch(0)
-        sizePolicy1.setHeightForWidth(
+        sizePolicy.setHeightForWidth(
             self.txt_constraint.sizePolicy().hasHeightForWidth()
         )
-        self.txt_constraint.setSizePolicy(sizePolicy1)
-        self.txt_constraint.setMaximumSize(QSize(16777215, 70))
+        self.txt_constraint.setSizePolicy(sizePolicy)
+        self.txt_constraint.setMinimumSize(QSize(0, 90))
+        self.txt_constraint.setMaximumSize(QSize(16777215, 90))
         self.txt_constraint.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self.txt_constraint.setTextInteractionFlags(
             Qt.TextSelectableByKeyboard | Qt.TextSelectableByMouse
@@ -67,7 +66,7 @@ class Ui_PMSlot11(object):
         self.scrollArea.setWidgetResizable(True)
         self.scrollAreaWidgetContents = QWidget()
         self.scrollAreaWidgetContents.setObjectName(u"scrollAreaWidgetContents")
-        self.scrollAreaWidgetContents.setGeometry(QRect(0, 0, 268, 446))
+        self.scrollAreaWidgetContents.setGeometry(QRect(0, 0, 268, 531))
         self.verticalLayout = QVBoxLayout(self.scrollAreaWidgetContents)
         self.verticalLayout.setObjectName(u"verticalLayout")
         self.gridLayout = QGridLayout()
@@ -77,21 +76,11 @@ class Ui_PMSlot11(object):
 
         self.gridLayout.addWidget(self.in_Wmag, 1, 0, 1, 1)
 
-        self.unit_Wmag = QLabel(self.scrollAreaWidgetContents)
-        self.unit_Wmag.setObjectName(u"unit_Wmag")
-
-        self.gridLayout.addWidget(self.unit_Wmag, 1, 2, 1, 1)
-
         self.in_W0 = QLabel(self.scrollAreaWidgetContents)
         self.in_W0.setObjectName(u"in_W0")
 
         self.gridLayout.addWidget(self.in_W0, 0, 0, 1, 1)
 
-        self.unit_W0 = QLabel(self.scrollAreaWidgetContents)
-        self.unit_W0.setObjectName(u"unit_W0")
-
-        self.gridLayout.addWidget(self.unit_W0, 0, 2, 1, 1)
-
         self.unit_H0 = QLabel(self.scrollAreaWidgetContents)
         self.unit_H0.setObjectName(u"unit_H0")
 
@@ -133,6 +122,20 @@ class Ui_PMSlot11(object):
 
         self.gridLayout.addWidget(self.lf_Wmag, 1, 1, 1, 1)
 
+        self.c_Wmag_unit = QComboBox(self.scrollAreaWidgetContents)
+        self.c_Wmag_unit.addItem("")
+        self.c_Wmag_unit.addItem("")
+        self.c_Wmag_unit.setObjectName(u"c_Wmag_unit")
+
+        self.gridLayout.addWidget(self.c_Wmag_unit, 1, 2, 1, 1)
+
+        self.c_W0_unit = QComboBox(self.scrollAreaWidgetContents)
+        self.c_W0_unit.addItem("")
+        self.c_W0_unit.addItem("")
+        self.c_W0_unit.setObjectName(u"c_W0_unit")
+
+        self.gridLayout.addWidget(self.c_W0_unit, 0, 2, 1, 1)
+
         self.verticalLayout.addLayout(self.gridLayout)
 
         self.verticalSpacer = QSpacerItem(
@@ -172,17 +175,29 @@ class Ui_PMSlot11(object):
                 "p, li { white-space: pre-wrap; }\n"
                 "</style></head><body style=\" font-family:'MS Shell Dlg 2'; font-size:7.8pt; font-weight:400; font-style:normal;\">\n"
                 '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-size:12pt; font-weight:600; text-decoration: underline;">Constraints :</span></p>\n'
-                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-size:14pt;">Wmag &lt;= W0</span></p></body></html>',
+                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-size:14pt;">Wmag &lt;= W0</span></p>\n'
+                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-size:14pt;">Wmag &lt; pi / p</span></p></body></html>',
                 None,
             )
         )
         self.in_Wmag.setText(QCoreApplication.translate("PMSlot11", u"Wmag", None))
-        self.unit_Wmag.setText(QCoreApplication.translate("PMSlot11", u"[rad]", None))
         self.in_W0.setText(QCoreApplication.translate("PMSlot11", u"W0", None))
-        self.unit_W0.setText(QCoreApplication.translate("PMSlot11", u"[rad]", None))
         self.unit_H0.setText(QCoreApplication.translate("PMSlot11", u"[m]", None))
         self.in_H0.setText(QCoreApplication.translate("PMSlot11", u"H0", None))
         self.unit_Hmag.setText(QCoreApplication.translate("PMSlot11", u"[m]", None))
         self.in_Hmag.setText(QCoreApplication.translate("PMSlot11", u"Hmag", None))
+        self.c_Wmag_unit.setItemText(
+            0, QCoreApplication.translate("PMSlot11", u"rad", None)
+        )
+        self.c_Wmag_unit.setItemText(
+            1, QCoreApplication.translate("PMSlot11", u"deg", None)
+        )
+
+        self.c_W0_unit.setItemText(
+            0, QCoreApplication.translate("PMSlot11", u"rad", None)
+        )
+        self.c_W0_unit.setItemText(
+            1, QCoreApplication.translate("PMSlot11", u"deg", None)
+        )
 
     # retranslateUi
