@@ -7,7 +7,7 @@ from PySide2.QtWidgets import QWidget
 from ......Classes.SlotW12 import SlotW12
 from ......GUI import gui_option
 from ......GUI.Dialog.DMachineSetup.SWSlot.PWSlot12.Gen_PWSlot12 import Gen_PWSlot12
-from ......Methods.Slot.Slot.check import SlotCheckError
+from ......Methods.Slot.Slot import SlotCheckError
 
 translate = PySide2.QtCore.QCoreApplication.translate
 
@@ -46,7 +46,7 @@ class PWSlot12(Gen_PWSlot12, QWidget):
         # Set unit name (m ou mm)
         wid_list = [self.unit_R1, self.unit_R2, self.unit_H0, self.unit_H1]
         for wid in wid_list:
-            wid.setText(gui_option.unit.get_m_name())
+            wid.setText("[" + gui_option.unit.get_m_name() + "]")
 
         # Fill the fields with the machine values (if they're filled)
         self.lf_R1.setValue(self.slot.R1)
@@ -132,13 +132,13 @@ class PWSlot12(Gen_PWSlot12, QWidget):
 
         # Check that everything is set
         if lam.slot.R1 is None:
-            return translate("You must set R1 !", "PWSlot12")
+            return "You must set R1 !"
         elif lam.slot.R2 is None:
-            return translate("You must set R2 !", "PWSlot12")
+            return "You must set R2 !"
         elif lam.slot.H0 is None:
-            return translate("You must set H0 !", "PWSlot12")
+            return "You must set H0 !"
         elif lam.slot.H1 is None:
-            return translate("You must set H1 !", "PWSlot12")
+            return "You must set H1 !"
 
         # Check that everything is set right
         # Constraints
@@ -151,9 +151,7 @@ class PWSlot12(Gen_PWSlot12, QWidget):
         try:
             yoke_height = lam.comp_height_yoke()
         except Exception as error:
-            return translate("Unable to compute yoke height:", "PWSlot12") + str(error)
+            return "Unable to compute yoke height:" + str(error)
 
         if yoke_height <= 0:
-            return translate(
-                "The slot height is greater than the lamination !", "PWSlot12"
-            )
+            return "The slot height is greater than the lamination !"
