@@ -14,7 +14,7 @@ def comp_masses(self):
     Returns
     -------
     M_dict: dict
-        Lamination mass dictionnary (Mtot, Mlam, Mwind) [kg]
+        Lamination mass dictionary (Mtot, Mlam, Mwind) [kg]
     """
 
     M_dict = LamSlot.comp_masses(self)
