@@ -4,7 +4,7 @@ from numpy import pi, sin
 
 
 def comp_resistance_wind(self, T=20, qs=3):
-    """Computation of the equivalent rotor resistance of a cage winding with 'qs' number of phases
+    """Computation of the equivalent rotor resistance per phase of a cage winding with 'qs' number of phases
 
     Parameters
     ----------
@@ -19,28 +19,31 @@ def comp_resistance_wind(self, T=20, qs=3):
          resistance of the rotor[Ohm]
 
     """
-    # calculate resistance ring
+    # calculate resistance ring at T degC
     alpha = self.ring_mat.elec.alpha
     rho20 = self.ring_mat.elec.rho
     rho = rho20 * (1 + alpha * (T - 20))
 
     Sring = self.comp_surface_ring()
     lring = self.comp_length_ring()
-    Zs = self.get_Zs()
+    Zr = self.get_Zs()
     P = self.get_pole_pair_number()
-
+    # total ring resistance (not yet divided by Zr to take average resistance seen by one bar)
     Rring = rho * lring / Sring
 
-    # calculate resistance rod
+    # calculate resistance rod at T degC
     alpha = self.winding.conductor.cond_mat.elec.alpha
     rho20 = self.winding.conductor.cond_mat.elec.rho
     rho = rho20 * (1 + alpha * (T - 20))
 
+    # active surface inside slot
     Srod = self.winding.conductor.comp_surface_active()
+    # total bar length inside lamination + outside lamination before end ring (#TODO Lewout should be 0 for molded cage, #TODO comp_length() should account for skew shape)
     lrod = self.comp_length() + 2 * self.winding.Lewout
+    # bar resistance
     Rrod = rho * lrod / Srod
 
-    # calculate total resistance
-    Rtot = Zs / qs * (Rrod + Rring / Zs / (2 * sin(pi * P / Zs) ** 2))
+    # average physical resistance per rotor bar (not yet transfered on stator side, per stator phase)
+    Rtot = Rrod + Rring / Zr / (2 * sin(pi * P / Zr) ** 2)
 
     return Rtot
