@@ -11,5 +11,7 @@ def comp_length_endwinding(self):
         End-winding length on one side for a half-turn [m].
     """
 
-    # TODO: compute it
-    return self.Lewout
+    if self.end_winding is None:
+        return self.Lewout
+    else:
+        return self.Lewout + self.end_winding.comp_length_endwinding()
