@@ -32,9 +32,9 @@ def comp_periodicity(self, wind_mat=None):
     # Summing on all the layers (Nlay_r and Nlay_theta)
     wind_mat2 = squeeze(wind_mat)
 
-    if wind_mat2.ndim == 4:
+    if wind_mat2.ndim == 4:  # rad and tan > 2
         Nlay = wind_mat2.shape[0] * wind_mat2.shape[1]
-        wind_mat2.reshape((Nlay, Zs, qs))
+        wind_mat2 = wind_mat2.reshape((Nlay, Zs, qs))
     elif wind_mat2.ndim == 2:
         Nlay = 1
         wind_mat2 = wind_mat2[None, :, :]
@@ -52,15 +52,18 @@ def comp_periodicity(self, wind_mat=None):
             wind_mat_ql_fft = fft(wind_mat2[l, :, q])
             # Find indices of nonzero amplitudes
             I0 = where(np_abs(wind_mat_ql_fft) > 1e-3)[0]
-            # Periodicity is given by the non zero lowest order
-            Nperw_ql = I0[0] if I0[0] != 0 else I0[1]
-            Nperw = gcd(Nperw, Nperw_ql)
-            if I0[0] == 0:
-                # Anti-periodicity is necessary false if there is a constant component
-                is_aper = False
+            if len(I0) == 0:  # This phase is not present in this layer
+                pass  # No impact on symmetry
             else:
-                # Anti-periodicity is true if all non-zero components are odd multiple of periodicity
-                is_aper = is_aper and np_all(mod(I0 / Nperw_ql, 2) == 1)
+                # Periodicity is given by the non zero lowest order
+                Nperw_ql = I0[0] if I0[0] != 0 else I0[1]
+                Nperw = gcd(Nperw, Nperw_ql)
+                if I0[0] == 0:
+                    # Anti-periodicity is necessary false if there is a constant component
+                    is_aper = False
+                else:
+                    # Anti-periodicity is true if all non-zero components are odd multiple of periodicity
+                    is_aper = is_aper and np_all(mod(I0 / Nperw_ql, 2) == 1)
 
             if Nperw == 1 and not is_aper:
                 # No need to further continue if there is no anti-periodicity
