@@ -1,18 +1,19 @@
 import numpy as np
 import matplotlib.pyplot as plt
 from matplotlib.colors import LinearSegmentedColormap
+from ....Methods.Output.XOutput import _get_symbol_data_
 
 
 def plot_generation(self, x_symbol, y_symbol, ax=None):
     """Plot every fitness values according to the two fitness
-    
+
     Parameters
     ----------
     self : XOutput
     obj1 : str
-        symbol of the ParamExplorer or the DataKeeper
+        symbol of the ParamExplorer, the OptiObjective or the DataKeeper
     obj2 : str
-        symbol of the ParamExplorer or the DataKeeper
+        symbol of the ParamExplorer, the OptiObjective or the DataKeeper
     """
 
     # TODO define the colormap according to Pyleecan graphical chart
@@ -20,43 +21,21 @@ def plot_generation(self, x_symbol, y_symbol, ax=None):
     cm = LinearSegmentedColormap.from_list(
         "colormap",
         [(35 / 255, 89 / 255, 133 / 255), (250 / 255, 202 / 255, 56 / 255)],
-        N=max(self["ngen"]) + 1,
+        N=max(self["ngen"].result) + 1,
     )
 
     # Get fitness and ngen
-    is_valid = np.array(self["is_valid"])
-    ngen = np.array(self["ngen"])
+    is_valid = np.array(self["is_valid"].result)
+    ngen = np.array(self["ngen"].result)
 
     # Keep only valid values
     indx = np.where(is_valid)[0]
 
     ngen = ngen[indx]
 
-    # Get x_data
-    if x_symbol in self.keys():  # DataKeeper
-        x_data = self[x_symbol]
-        x_values = np.array(x_data.result)[indx]
-    else:  # ParamSetter
-        x_data = self.get_paramexplorer(x_symbol)
-        x_values = np.array(x_data.value)[indx]
-
-    # x_label definition
-    x_label = x_symbol
-    if x_data.unit not in ["", None]:
-        x_label += " [{}]".format(x_data.unit)
-
-    # Get y_data
-    if y_symbol in self.keys():  # DataKeeper
-        y_data = self[y_symbol]
-        y_values = np.array(y_data.result)[indx]
-    else:  # ParamSetter
-        y_data = self.get_paramexplorer(y_symbol)
-        y_values = np.array(y_data.value)[indx]
-
-    # y_label definition
-    y_label = y_symbol
-    if y_data.unit not in ["", None]:
-        y_label += " [{}]".format(y_data.unit)
+    # get data and labels
+    x_values, x_label = _get_symbol_data_(self, x_symbol, indx)
+    y_values, y_label = _get_symbol_data_(self, y_symbol, indx)
 
     if ax is None:
         fig, ax = plt.subplots()
@@ -77,7 +56,6 @@ def plot_generation(self, x_symbol, y_symbol, ax=None):
         ax.set_xlabel(x_label)
         ax.set_ylabel(y_label)
         ax.set_title("Fitness values for each individual")
-
         fig.show()
 
     else:
