@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from ....Functions.Electrical.coordinate_transformation import n2dq
+from ....Functions.Electrical.dqh_transformation import n2dqh
 from numpy import split, transpose, mean, pi
 
 import matplotlib.pyplot as plt
@@ -19,16 +19,14 @@ def gen_drive(self, output):
 
     qs = output.simu.machine.stator.winding.qs
     felec = output.elec.felec
-    time = output.elec.Time.get_values()
+    time = output.elec.axes_dict["time"].get_values()
 
     # Compute voltage
     Voltage = self.drive.get_wave()
 
     # d,q transform
     voltage = Voltage.values
-    voltage_dq = split(
-        n2dq(transpose(voltage), -2 * pi * felec * time, n=qs), 2, axis=1
-    )
+    voltage_dq = split(n2dqh(transpose(voltage), -2 * pi * felec * time), 2, axis=1)
 
     fig = plt.figure()
     plt.plot(time[:50], voltage[0, :50], color="tab:blue", label="A")
