@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from ....Functions.Electrical.coordinate_transformation import n2dq
+from ....Functions.Electrical.dqh_transformation import n2dqh
 from numpy import split, transpose, mean, pi
 
 import matplotlib.pyplot as plt
@@ -30,7 +30,7 @@ def gen_drive(self, output):
     # d,q transform
     voltage = Voltage.values
     voltage_dq = split(
-        n2dq(transpose(voltage), -2 * pi * felec * time, n=qs), 2, axis=1
+        n2dqh(transpose(voltage), -2 * pi * felec * time, n=qs), 2, axis=1
     )
 
     fig = plt.figure()
