@@ -1,4 +1,7 @@
-# -*- coding: utf-8 -*-
+# Init conventions for input generation
+ROT_DIR_REF = -1
+CURRENT_DIR_REF = -1
+PHASE_DIR_REF = -1
 
 
 class InputError(Exception):
