@@ -19,11 +19,11 @@ def set_OP_from_array(self, OP_matrix, type_OP_matrix=1, index=0):
     assert index < OP_matrix.shape[0]
     assert type_OP_matrix in [0, 1]
 
-    self.N0 = OP_matrix[index, 0]
+    self.OP.N0 = OP_matrix[index, 0]
     if type_OP_matrix == 1:
-        self.Id_ref = OP_matrix[index, 1]
-        self.Iq_ref = OP_matrix[index, 2]
+        self.OP.Id_ref = OP_matrix[index, 1]
+        self.OP.Iq_ref = OP_matrix[index, 2]
     else:
         self.set_Id_Iq(I0=OP_matrix[index, 1], Phi0=OP_matrix[index, 2])
     if OP_matrix.shape[1] > 3:
-        self.Tem_av_ref = OP_matrix[index, 3]
+        self.OP.Tem_av_ref = OP_matrix[index, 3]
