@@ -84,7 +84,7 @@ def solve_FEA(self, output, sym, angle, time, angle_rotor, Is, Ir):
     BHr = output.geo.rotor.BH_curve  # Rotor B(H) curve
     # Is = output.elec.Is  # Stator currents waveforms
     # Ir = output.elec.Ir  # Rotor currents waveforms
-    Speed = output.elec.N0
+    Speed = output.elec.OP.get_N0()
     rotor_mat_file = join(project_name, "rotor_material.pmf")
     stator_mat_file = join(project_name, "stator_material.pmf")
 
@@ -353,7 +353,7 @@ def solve_FEA(self, output, sym, angle, time, angle_rotor, Is, Ir):
         degrees_step = 1  # Fixed for now
         current_angle = 0 - pp * degrees_step * skip_steps
         angle_shift = self.angle_rotor_shift - self.angle_stator_shift
-        rotor_init_pos = machine.comp_angle_offset_initial() + angle_shift
+        rotor_init_pos = machine.comp_angle_rotor_initial() + angle_shift
         rotor_d_axis = machine.rotor.comp_angle_d_axis() * 180.0 / pi
         Ncond = 1  # Fixed for Now
         Cp = 1  # Fixed for Now
