@@ -1,19 +1,18 @@
-# -*- coding: utf-8 -*-
-from os.path import join
-
 from numpy import zeros
 
+from SciDataTool import Data1D
+
+from ....Classes._FEMMHandler import _FEMMHandler
+from ....Classes.OutMagFEMM import OutMagFEMM
+
 from ....Functions.labels import STATOR_LAB
 from ....Functions.FEMM.draw_FEMM import draw_FEMM
-from ....Classes._FEMMHandler import _FEMMHandler
-from ....Classes.OutMagFEMM import OutMagFEMM
 from ....Functions.MeshSolution.build_solution_data import build_solution_data
 from ....Functions.MeshSolution.build_meshsolution import build_meshsolution
 from ....Functions.MeshSolution.build_solution_vector import build_solution_vector
-from SciDataTool import Data1D
 
 
-def comp_flux_airgap(self, output, axes_dict):
+def comp_flux_airgap(self, output, axes_dict, Is=None, Ir=None):
     """Build and solve FEMM model to calculate and store magnetic quantities
 
     Parameters
@@ -49,8 +48,8 @@ def comp_flux_airgap(self, output, axes_dict):
         output.mag.internal = OutMagFEMM()
 
     # Get time and angular axes
-    Angle = axes_dict["Angle"]
-    Time = axes_dict["Time"]
+    Angle = axes_dict["angle"]
+    Time = axes_dict["time"]
 
     # Set the angular symmetry factor according to the machine and check if it is anti-periodic
     sym, is_antiper_a = Angle.get_periodicity()
@@ -75,18 +74,6 @@ def comp_flux_airgap(self, output, axes_dict):
     # Get rotor angular position
     angle_rotor = output.get_angle_rotor()[0:Nt]
 
-    # Interpolate current on magnetic model time axis
-    # Get stator current from elec out
-    if self.is_mmfs:
-        Is = output.elec.comp_I_mag(time, is_stator=True)
-    else:
-        Is = None
-    # Get rotor current from elec out
-    if self.is_mmfr:
-        Ir = output.elec.comp_I_mag(time, is_stator=False)
-    else:
-        Ir = None
-
     # Setup the FEMM simulation
     # Geometry building and assigning property in FEMM
     # Instanciate a new FEMM
@@ -102,7 +89,8 @@ def comp_flux_airgap(self, output, axes_dict):
             sym=sym,
             is_antiper=is_antiper_a,
             type_calc_leakage=self.type_calc_leakage,
-            is_remove_vent=self.is_remove_vent,
+            is_remove_ventS=self.is_remove_ventS,
+            is_remove_ventR=self.is_remove_ventR,
             is_remove_slotS=self.is_remove_slotS,
             is_remove_slotR=self.is_remove_slotR,
             type_BH_stator=self.type_BH_stator,
@@ -142,7 +130,7 @@ def comp_flux_airgap(self, output, axes_dict):
         femm.closefemm()
         output.mag.internal.handler_list.remove(femm)
         # With parallelization
-        B_elem, H_elem, mu_elem, meshFEMM, groups = self.solve_FEMM_parallel(
+        B_elem, H_elem, mu_elem, A_node, meshFEMM, groups = self.solve_FEMM_parallel(
             femm,
             output,
             out_dict,
@@ -156,7 +144,7 @@ def comp_flux_airgap(self, output, axes_dict):
         )
     else:
         # Without parallelization
-        B_elem, H_elem, mu_elem, meshFEMM, groups = self.solve_FEMM(
+        B_elem, H_elem, mu_elem, A_node, meshFEMM, groups = self.solve_FEMM(
             femm,
             output,
             out_dict,
@@ -179,7 +167,7 @@ def comp_flux_airgap(self, output, axes_dict):
     if STATOR_LAB + "-0" in out_dict["Phi_wind"].keys():
         out_dict["Phi_wind_stator"] = out_dict["Phi_wind"][STATOR_LAB + "-0"]
 
-        # Store mesh data & solution
+    # Store mesh data & solution
     if self.is_get_meshsolution and B_elem is not None:
 
         # Define axis
@@ -210,7 +198,20 @@ def comp_flux_airgap(self, output, axes_dict):
             unit="H/m",
         )
 
-        list_solution = [B_sol, H_sol, mu_sol]
+        indices_nodes = meshFEMM[0].node.indice
+        Indices_Nodes = Data1D(name="indice", values=indices_nodes, is_components=True)
+        axis_list_node = [Time, Indices_Nodes]
+
+        A_sol = build_solution_data(
+            field=A_node,
+            axis_list=axis_list_node,
+            name="Magnetic Potential Vector",
+            symbol="A_z",
+            unit="T.m",
+        )
+        A_sol.type_cell = "node"
+
+        list_solution = [B_sol, H_sol, mu_sol, A_sol]
 
         out_dict["meshsolution"] = build_meshsolution(
             list_solution=list_solution,
