@@ -1,9 +1,8 @@
-from os.path import basename, splitext
+from os import remove
+from os.path import splitext, isfile
 
 from numpy import zeros, pi, roll, cos, sin
 
-# from scipy.interpolate import interp1d
-
 from ....Classes._FEMMHandler import _FEMMHandler
 from ....Functions.FEMM.update_FEMM_simulation import update_FEMM_simulation
 from ....Functions.FEMM.comp_FEMM_torque import comp_FEMM_torque
@@ -74,22 +73,48 @@ def solve_FEMM(
 
     Returns
     -------
+    B: ndarray
+        3D Magnetic flux density for all time steps and each element (Nt, Nelem, 3) [T]
+    H : ndarray
+        3D Magnetic field for all time steps and each element (Nt, Nelem, 3) [A/m]
+    mu : ndarray
+        Magnetic relative permeability for all time steps and each element (Nt, Nelem) []
+    mesh: MeshMat
+        Object containing magnetic mesh at first time step
+    groups: dict
+        Dict whose values are group label and values are array of indices of related elements
 
     """
-    # Open FEMM file if not None, else it is already open
+
+    logger = self.get_logger()
+    is_sliding_band = self.is_sliding_band
+
     if filename is not None:
+        # Open FEMM instance if filename is not None (parallel case)
         try:
-            # Open the document
+            # Try to open FEMM instance if handler already exists (first parallelized handler)
             femm.openfemm(1)
-        except:
+        except Exception:
             # Create a new FEMM handler in case of parallelization on another FEMM instance
             femm = _FEMMHandler()
             output.mag.internal.handler_list.append(femm)
-            # Open the document
+            # Open a new FEMM instance associated to new handler
             femm.openfemm(1)
 
-        # Import FEMM file
+        # Open FEMM file
         femm.opendocument(filename)
+    else:
+        # FEMM instance and file is already open, get filename from output
+        filename = self.get_path_save_fem(output)
+
+    if is_sliding_band and self.is_set_previous:
+        # Check result .ans file existence and delete it if it exists
+        ans_file = (
+            (splitext(filename)[0] + ".ans").replace("\\", "/").replace("//", "/")
+        )
+        if isfile(ans_file):
+            logger.debug("Delete existing result .ans file at: " + ans_file)
+            remove(ans_file)
 
     # Take last time step at Nt by default
     if end_t is None:
@@ -105,6 +130,7 @@ def solve_FEMM(
         Rag = machine.comp_Rgap_mec()
 
     L1 = machine.stator.comp_length()
+    L2 = machine.rotor.comp_length()
     save_path = self.get_path_save(output)
     is_internal_rotor = machine.rotor.is_internal
     if "Phi_wind" in out_dict:
@@ -123,15 +149,16 @@ def solve_FEMM(
     mu_elem = None
     meshFEMM = None
     groups = None
+    A_node = None
 
     # Compute the data for each time step
     for ii in range(start_t, end_t):
         if Nt > 1:
-            self.get_logger().info(
+            logger.info(
                 "Solving time step " + str(ii + 1) + " / " + str(Nt) + " in FEMM"
             )
         else:
-            self.get_logger().info("Computing Airgap Flux in FEMM")
+            logger.info("Computing Airgap Flux in FEMM")
         # Update rotor position and currents
         update_FEMM_simulation(
             femm=femm,
@@ -143,14 +170,17 @@ def solve_FEMM(
             Ir=Ir,
             ii=ii,
         )
-        # try "previous solution" for speed up of FEMM calculation
-        if self.is_sliding_band:
-            try:
-                base = basename(self.get_path_save_fem(output))
-                ans_file = splitext(base)[0] + ".ans"
+
+        # Check if there is a previous solution file to speed up non-linear iterations
+        if is_sliding_band and self.is_set_previous and ii > start_t:
+            if isfile(ans_file):
+                # Setup .ans file path in FEMM model
                 femm.mi_setprevious(ans_file, 0)
-            except:
-                pass
+            else:
+                logger.warning("Cannot reuse result .ans file: " + ans_file)
+        else:
+            # Make sure that no file path is filled in FEMM model
+            femm.mi_setprevious("", 0)
 
         # Run the computation
         femm.mi_analyze()
@@ -182,15 +212,15 @@ def solve_FEMM(
                     qs[key],
                     Npcp[key],
                     is_stator=machine.get_lam_by_label(key).is_stator,
-                    Lfemm=FEMM_dict["Lfemm"],
                     L1=L1,
+                    L2=L2,
                     sym=sym,
                 )
 
         # Load mesh data & solution
-        if (self.is_sliding_band or Nt == 1) and (self.is_get_meshsolution):
+        if self.is_get_meshsolution and (is_sliding_band or Nt == 1):
             # Get mesh data and magnetic quantities from .ans file
-            tmpmeshFEMM, tmpB, tmpH, tmpmu, tmpgroups = self.get_meshsolution(
+            tmpmeshFEMM, tmpB, tmpH, tmpmu, tmpA, tmpgroups = self.get_meshsolution(
                 femm,
                 save_path,
                 j_t0=ii,
@@ -205,10 +235,12 @@ def solve_FEMM(
                 meshFEMM = [tmpmeshFEMM]
                 groups = tmpgroups
                 Nelem = meshFEMM[0].cell["triangle"].nb_cell
+                Nnode = meshFEMM[0].node.nb_node
                 Nt0 = end_t - start_t
                 B_elem = zeros([Nt0, Nelem, 3])
                 H_elem = zeros([Nt0, Nelem, 3])
                 mu_elem = zeros([Nt0, Nelem])
+                A_node = zeros([Nt0, Nnode])
 
             # Shift time index ii in case start_t is not 0 (parallelization)
             ii0 = ii - start_t
@@ -216,6 +248,7 @@ def solve_FEMM(
             B_elem[ii0, :, 0:2] = tmpB
             H_elem[ii0, :, 0:2] = tmpH
             mu_elem[ii0, :] = tmpmu
+            A_node[ii0, :] = tmpA
 
     # Shift to take into account stator position
     if self.angle_stator_shift != 0:
@@ -223,11 +256,6 @@ def solve_FEMM(
         out_dict["Br"] = roll(out_dict["Br"], roll_id, axis=1)
         out_dict["Bt"] = roll(out_dict["Bt"], roll_id, axis=1)
 
-        # # Interpolate on updated angular position # TODO to improve accuracy
-        # angle_new = (angle - self.angle_stator_shift) % (2 * pi / sym)
-        # out_dict["Br"] = interp1d(append(angle, 2 * pi / sym), append(out_dict["Br"], out_dict["Br"][:,0]), axis=1)[angle_new]
-        # out_dict["Bt"] = interp1d(append(angle, 2 * pi / sym), append(out_dict["Bt"], out_dict["Bt"][:,0]), axis=1)[angle_new]
-
     # Close FEMM handler
     if is_close_femm:
         femm.closefemm()
@@ -235,4 +263,4 @@ def solve_FEMM(
 
     out_dict["Rag"] = Rag
 
-    return B_elem, H_elem, mu_elem, meshFEMM, groups
+    return B_elem, H_elem, mu_elem, A_node, meshFEMM, groups
