@@ -2,21 +2,24 @@ from ....Classes._frozen import FrozenClass
 from numpy import ndarray
 
 
-def as_dict(self):
-    """Convert this object in a json seriable dict (can be use in __init__)"""
-
+def as_dict(self, **kwargs):
+    """
+    Convert this object in a json serializable dict (can be use in __init__).
+    Optional keyword input parameter is for internal use only
+    and may prevent json serializability.
+    """
     # Get the properties inherited from ParamExplorer
-    ParamExplorerSet_dict = super(type(self), self).as_dict()
-    ParamExplorerSet_dict["value"] = (
-        self.value.copy() if self.value is not None else None
-    )
+    ParamExplorerSet_dict = super(type(self), self).as_dict(**kwargs)
     if self.value is None:
         ParamExplorerSet_dict["value"] = None
     else:
         ParamExplorerSet_dict["value"] = list()
         for obj in self.value:
             if isinstance(obj, FrozenClass):
-                ParamExplorerSet_dict["value"].append(obj.as_dict())
+                if "SciDataTool" in obj.__class__.__module__:
+                    ParamExplorerSet_dict["value"].append(obj.as_dict())
+                else:
+                    ParamExplorerSet_dict["value"].append(obj.as_dict(**kwargs))
             elif isinstance(obj, ndarray):
                 ParamExplorerSet_dict["value"].append(obj.tolist())
             else:
