@@ -4,7 +4,7 @@ from numpy import arcsin, pi
 
 
 def comp_alpha(self):
-    """The opening angle with a W3 teeth width and Rbo - H0 radius
+    """The opening angle with a W3 teeth width and Rext - H0 radius
 
     Parameters
     ----------
@@ -17,9 +17,9 @@ def comp_alpha(self):
         Angle between P1 and P9 (cf schematics) [rad]
 
     """
-    Rbo = self.get_Rbo()
+    Rext = self.get_Rext()
 
-    alpha_tooth = 2 * arcsin(self.W3 / (2 * (Rbo - self.H0)))
+    alpha_tooth = 2 * arcsin(self.W3 / (2 * (Rext - self.H0)))
     slot_pitch = 2 * pi / self.Zh
 
     return slot_pitch - alpha_tooth
