@@ -29,10 +29,15 @@ def build_geometry(self):
     R0 = ((self.W0 / 2) ** 2 + self.H0 ** 2) / (2 * self.H0)
 
     # Creation of curve
-    curve_list = list()
     if self.is_outwards():
-        curve_list.append(Arc1(begin=Z1, end=Z2, radius=-R0, is_trigo_direction=True))
+        full_arc = Arc1(begin=Z1, end=Z2, radius=-R0, is_trigo_direction=True)
     else:
-        curve_list.append(Arc1(begin=Z1, end=Z2, radius=R0, is_trigo_direction=False))
+        full_arc = Arc1(begin=Z1, end=Z2, radius=R0, is_trigo_direction=False)
+    # Split arc to avoid angle > 180 deg (for FEMM)
+    curve_list = list()
+    curve_list.append(full_arc.copy())
+    curve_list[-1].split_half(is_begin=True)
+    curve_list.append(full_arc.copy())
+    curve_list[-1].split_half(is_begin=False)
 
     return curve_list
