@@ -1,4 +1,5 @@
-from ....Methods.Slot.Slot.check import SlotCheckError
+from ....Methods.Slot.Slot import SlotCheckError
+from ....Methods.Slot.Slot19 import *
 
 
 def check(self):
@@ -15,10 +16,3 @@ def check(self):
     """
     if self.H0 < self.W0 / 2:
         raise SC_WHCheckError("You must have W0/2 <= H0")
-
-
-class SC_WHCheckError(SlotCheckError):
-    """Raised when a SlotCirc has self.H0 < self.W0/2
-    """
-
-    pass
