@@ -21,7 +21,5 @@ def check(self):
         raise SlotCheckError("SlotM17 must be inside a lamination")
     if self.Zs != 2:
         raise SlotCheckError("SlotM17 must have p=1")
-    if not self.parent.is_internal or self.parent.Rint != 0:
-        raise SlotCheckError(
-            "SlotM17 must be inside an internal lamination with Rint=0"
-        )
+    if not self.parent.is_internal:
+        raise SlotCheckError("SlotM17 must be inside an internal lamination")
