@@ -4,7 +4,7 @@ import shutil
 import sys
 from json import load
 from logging import getLogger
-from os.path import abspath, dirname, isdir, isfile, join, normpath, realpath
+from os.path import abspath, dirname, basename, join, normpath, realpath
 from matplotlib.colors import ListedColormap
 from matplotlib.cm import get_cmap, register_cmap
 from numpy import load as np_load
@@ -38,5 +38,10 @@ TEST_DIR = join(ROOT_DIR, "Tests").replace("\\", "/")
 
 CONF_PATH = join(USER_DIR, "main_config_dict.json")
 
+# Matplotlib definitions
+# Get a "sans-serif" font as default (works for Linux and Windows)
+DEFAULT_FONT = font_manager.FontProperties(family=["sans-serif"]).get_name()
+DEFAULT_COLOR_MAP = "RdBu_r"
+
 # Load the config file (create one if it doesn't exist)
 config_dict = get_config_dict()
